import numpy as np

from debyetools.pairanalysis import pair_analysis

formula = 'AABA'
cutoff = 10
basis_vectors = np.array([[0,0,0], [.5,.5,0], [.5,0,.5], [0,.5,.5]])
primitive_cell = np.array([[4,0,0] ,[0,4,0] ,[0,0,4]])
pa_result = pair_analysis(formula, cutoff, basis_vectors, primitive_cell)
distances , num_pairs_per_formula , combs_types = pa_result
print('distances| # of pairs per type')
print('         | '+'  '.join(['%s' for _ in combs_types])%tuple(combs_types))
for d, n in zip( distances , num_pairs_per_formula ):
    print(' %.6f' % (d) + '| ' + ' '.join([' %.2f' for _ in n]) % tuple(n))




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'dialog_periodictable.ui'
##
## Created by: Qt User Interface Compiler version 6.7.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QDialog, QGridLayout, QHBoxLayout,
    QLabel, QLineEdit, QPushButton, QSizePolicy,
    QVBoxLayout, QWidget)

from debyetools.tpropsgui.custom_widgets import CountingButton

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        if not Dialog.objectName():
            Dialog.setObjectName(u"Dialog")
        Dialog.setWindowModality(Qt.WindowModality.WindowModal)
        Dialog.resize(470, 299)
        self.verticalLayout = QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.gridLayout = QGridLayout()
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName(u"gridLayout")
        self.pushB88 = CountingButton(Dialog)
        self.pushB88.setObjectName(u"pushB88")
        sizePolicy = QSizePolicy(QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushB88.sizePolicy().hasHeightForWidth())
        self.pushB88.setSizePolicy(sizePolicy)
        self.pushB88.setMinimumSize(QSize(25, 25))
        self.pushB88.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB88, 9, 3, 1, 1)

        self.pushB66 = CountingButton(Dialog)
        self.pushB66.setObjectName(u"pushB66")
        sizePolicy.setHeightForWidth(self.pushB66.sizePolicy().hasHeightForWidth())
        self.pushB66.setSizePolicy(sizePolicy)
        self.pushB66.setMinimumSize(QSize(25, 25))
        self.pushB66.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB66, 8, 13, 1, 1)

        self.pushB85 = CountingButton(Dialog)
        self.pushB85.setObjectName(u"pushB85")
        sizePolicy.setHeightForWidth(self.pushB85.sizePolicy().hasHeightForWidth())
        self.pushB85.setSizePolicy(sizePolicy)
        self.pushB85.setMinimumSize(QSize(25, 25))
        self.pushB85.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB85, 5, 18, 1, 1)

        self.pushB75 = CountingButton(Dialog)
        self.pushB75.setObjectName(u"pushB75")
        sizePolicy.setHeightForWidth(self.pushB75.sizePolicy().hasHeightForWidth())
        self.pushB75.setSizePolicy(sizePolicy)
        self.pushB75.setMinimumSize(QSize(25, 25))
        self.pushB75.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB75, 5, 8, 1, 1)

        self.pushB101 = CountingButton(Dialog)
        self.pushB101.setObjectName(u"pushB101")
        sizePolicy.setHeightForWidth(self.pushB101.sizePolicy().hasHeightForWidth())
        self.pushB101.setSizePolicy(sizePolicy)
        self.pushB101.setMinimumSize(QSize(25, 25))
        self.pushB101.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB101, 9, 16, 1, 1)

        self.pushB110 = CountingButton(Dialog)
        self.pushB110.setObjectName(u"pushB110")
        sizePolicy.setHeightForWidth(self.pushB110.sizePolicy().hasHeightForWidth())
        self.pushB110.setSizePolicy(sizePolicy)
        self.pushB110.setMinimumSize(QSize(25, 25))
        self.pushB110.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB110, 6, 11, 1, 1)

        self.pushB82 = CountingButton(Dialog)
        self.pushB82.setObjectName(u"pushB82")
        sizePolicy.setHeightForWidth(self.pushB82.sizePolicy().hasHeightForWidth())
        self.pushB82.setSizePolicy(sizePolicy)
        self.pushB82.setMinimumSize(QSize(25, 25))
        self.pushB82.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB82, 5, 15, 1, 1)

        self.pushB70 = CountingButton(Dialog)
        self.pushB70.setObjectName(u"pushB70")
        sizePolicy.setHeightForWidth(self.pushB70.sizePolicy().hasHeightForWidth())
        self.pushB70.setSizePolicy(sizePolicy)
        self.pushB70.setMinimumSize(QSize(25, 25))
        self.pushB70.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB70, 8, 17, 1, 1)

        self.pushB116 = CountingButton(Dialog)
        self.pushB116.setObjectName(u"pushB116")
        sizePolicy.setHeightForWidth(self.pushB116.sizePolicy().hasHeightForWidth())
        self.pushB116.setSizePolicy(sizePolicy)
        self.pushB116.setMinimumSize(QSize(25, 25))
        self.pushB116.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB116, 6, 17, 1, 1)

        self.pushB72 = CountingButton(Dialog)
        self.pushB72.setObjectName(u"pushB72")
        sizePolicy.setHeightForWidth(self.pushB72.sizePolicy().hasHeightForWidth())
        self.pushB72.setSizePolicy(sizePolicy)
        self.pushB72.setMinimumSize(QSize(25, 25))
        self.pushB72.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB72, 5, 5, 1, 1)

        self.pushB114 = CountingButton(Dialog)
        self.pushB114.setObjectName(u"pushB114")
        sizePolicy.setHeightForWidth(self.pushB114.sizePolicy().hasHeightForWidth())
        self.pushB114.setSizePolicy(sizePolicy)
        self.pushB114.setMinimumSize(QSize(25, 25))
        self.pushB114.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB114, 6, 15, 1, 1)

        self.pushB22 = CountingButton(Dialog)
        self.pushB22.setObjectName(u"pushB22")
        sizePolicy.setHeightForWidth(self.pushB22.sizePolicy().hasHeightForWidth())
        self.pushB22.setSizePolicy(sizePolicy)
        self.pushB22.setMinimumSize(QSize(25, 25))
        self.pushB22.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB22, 3, 5, 1, 1)

        self.pushB103 = CountingButton(Dialog)
        self.pushB103.setObjectName(u"pushB103")
        sizePolicy.setHeightForWidth(self.pushB103.sizePolicy().hasHeightForWidth())
        self.pushB103.setSizePolicy(sizePolicy)
        self.pushB103.setMinimumSize(QSize(25, 25))
        self.pushB103.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB103, 6, 4, 1, 1)

        self.pushB35 = CountingButton(Dialog)
        self.pushB35.setObjectName(u"pushB35")
        sizePolicy.setHeightForWidth(self.pushB35.sizePolicy().hasHeightForWidth())
        self.pushB35.setSizePolicy(sizePolicy)
        self.pushB35.setMinimumSize(QSize(25, 25))
        self.pushB35.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB35, 3, 18, 1, 1)

        self.pushB12 = CountingButton(Dialog)
        self.pushB12.setObjectName(u"pushB12")
        sizePolicy.setHeightForWidth(self.pushB12.sizePolicy().hasHeightForWidth())
        self.pushB12.setSizePolicy(sizePolicy)
        self.pushB12.setMinimumSize(QSize(25, 25))
        self.pushB12.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB12, 2, 13, 1, 1)

        self.pushB18 = CountingButton(Dialog)
        self.pushB18.setObjectName(u"pushB18")
        sizePolicy.setHeightForWidth(self.pushB18.sizePolicy().hasHeightForWidth())
        self.pushB18.setSizePolicy(sizePolicy)
        self.pushB18.setMinimumSize(QSize(25, 25))
        self.pushB18.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB18, 3, 1, 1, 1)

        self.pushB60 = CountingButton(Dialog)
        self.pushB60.setObjectName(u"pushB60")
        sizePolicy.setHeightForWidth(self.pushB60.sizePolicy().hasHeightForWidth())
        self.pushB60.setSizePolicy(sizePolicy)
        self.pushB60.setMinimumSize(QSize(25, 25))
        self.pushB60.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB60, 8, 7, 1, 1)

        self.pushB98 = CountingButton(Dialog)
        self.pushB98.setObjectName(u"pushB98")
        sizePolicy.setHeightForWidth(self.pushB98.sizePolicy().hasHeightForWidth())
        self.pushB98.setSizePolicy(sizePolicy)
        self.pushB98.setMinimumSize(QSize(25, 25))
        self.pushB98.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB98, 9, 13, 1, 1)

        self.pushB100 = CountingButton(Dialog)
        self.pushB100.setObjectName(u"pushB100")
        sizePolicy.setHeightForWidth(self.pushB100.sizePolicy().hasHeightForWidth())
        self.pushB100.setSizePolicy(sizePolicy)
        self.pushB100.setMinimumSize(QSize(25, 25))
        self.pushB100.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB100, 9, 15, 1, 1)

        self.pushB54 = CountingButton(Dialog)
        self.pushB54.setObjectName(u"pushB54")
        sizePolicy.setHeightForWidth(self.pushB54.sizePolicy().hasHeightForWidth())
        self.pushB54.setSizePolicy(sizePolicy)
        self.pushB54.setMinimumSize(QSize(25, 25))
        self.pushB54.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB54, 5, 1, 1, 1)

        self.pushB79 = CountingButton(Dialog)
        self.pushB79.setObjectName(u"pushB79")
        sizePolicy.setHeightForWidth(self.pushB79.sizePolicy().hasHeightForWidth())
        self.pushB79.setSizePolicy(sizePolicy)
        self.pushB79.setMinimumSize(QSize(25, 25))
        self.pushB79.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB79, 5, 12, 1, 1)

        self.pushB11 = CountingButton(Dialog)
        self.pushB11.setObjectName(u"pushB11")
        sizePolicy.setHeightForWidth(self.pushB11.sizePolicy().hasHeightForWidth())
        self.pushB11.setSizePolicy(sizePolicy)
        self.pushB11.setMinimumSize(QSize(25, 25))
        self.pushB11.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB11, 2, 2, 1, 1)

        self.pushB63 = CountingButton(Dialog)
        self.pushB63.setObjectName(u"pushB63")
        sizePolicy.setHeightForWidth(self.pushB63.sizePolicy().hasHeightForWidth())
        self.pushB63.setSizePolicy(sizePolicy)
        self.pushB63.setMinimumSize(QSize(25, 25))
        self.pushB63.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB63, 8, 10, 1, 1)

        self.pushB91 = CountingButton(Dialog)
        self.pushB91.setObjectName(u"pushB91")
        sizePolicy.setHeightForWidth(self.pushB91.sizePolicy().hasHeightForWidth())
        self.pushB91.setSizePolicy(sizePolicy)
        self.pushB91.setMinimumSize(QSize(25, 25))
        self.pushB91.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB91, 9, 6, 1, 1)

        self.pushB42 = CountingButton(Dialog)
        self.pushB42.setObjectName(u"pushB42")
        sizePolicy.setHeightForWidth(self.pushB42.sizePolicy().hasHeightForWidth())
        self.pushB42.setSizePolicy(sizePolicy)
        self.pushB42.setMinimumSize(QSize(25, 25))
        self.pushB42.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB42, 4, 7, 1, 1)

        self.pushB62 = CountingButton(Dialog)
        self.pushB62.setObjectName(u"pushB62")
        sizePolicy.setHeightForWidth(self.pushB62.sizePolicy().hasHeightForWidth())
        self.pushB62.setSizePolicy(sizePolicy)
        self.pushB62.setMinimumSize(QSize(25, 25))
        self.pushB62.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB62, 8, 9, 1, 1)

        self.pushB64 = CountingButton(Dialog)
        self.pushB64.setObjectName(u"pushB64")
        sizePolicy.setHeightForWidth(self.pushB64.sizePolicy().hasHeightForWidth())
        self.pushB64.setSizePolicy(sizePolicy)
        self.pushB64.setMinimumSize(QSize(25, 25))
        self.pushB64.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB64, 8, 11, 1, 1)

        self.pushB0 = CountingButton(Dialog)
        self.pushB0.setObjectName(u"pushB0")
        sizePolicy.setHeightForWidth(self.pushB0.sizePolicy().hasHeightForWidth())
        self.pushB0.setSizePolicy(sizePolicy)
        self.pushB0.setMinimumSize(QSize(25, 25))
        self.pushB0.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB0, 0, 1, 1, 1)

        self.pushB69 = CountingButton(Dialog)
        self.pushB69.setObjectName(u"pushB69")
        sizePolicy.setHeightForWidth(self.pushB69.sizePolicy().hasHeightForWidth())
        self.pushB69.setSizePolicy(sizePolicy)
        self.pushB69.setMinimumSize(QSize(25, 25))
        self.pushB69.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB69, 8, 16, 1, 1)

        self.pushB50 = CountingButton(Dialog)
        self.pushB50.setObjectName(u"pushB50")
        sizePolicy.setHeightForWidth(self.pushB50.sizePolicy().hasHeightForWidth())
        self.pushB50.setSizePolicy(sizePolicy)
        self.pushB50.setMinimumSize(QSize(25, 25))
        self.pushB50.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB50, 4, 15, 1, 1)

        self.pushB29 = CountingButton(Dialog)
        self.pushB29.setObjectName(u"pushB29")
        sizePolicy.setHeightForWidth(self.pushB29.sizePolicy().hasHeightForWidth())
        self.pushB29.setSizePolicy(sizePolicy)
        self.pushB29.setMinimumSize(QSize(25, 25))
        self.pushB29.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB29, 3, 12, 1, 1)

        self.pushB96 = CountingButton(Dialog)
        self.pushB96.setObjectName(u"pushB96")
        sizePolicy.setHeightForWidth(self.pushB96.sizePolicy().hasHeightForWidth())
        self.pushB96.setSizePolicy(sizePolicy)
        self.pushB96.setMinimumSize(QSize(25, 25))
        self.pushB96.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB96, 9, 11, 1, 1)

        self.pushB38 = CountingButton(Dialog)
        self.pushB38.setObjectName(u"pushB38")
        sizePolicy.setHeightForWidth(self.pushB38.sizePolicy().hasHeightForWidth())
        self.pushB38.setSizePolicy(sizePolicy)
        self.pushB38.setMinimumSize(QSize(25, 25))
        self.pushB38.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB38, 4, 3, 1, 1)

        self.pushB43 = CountingButton(Dialog)
        self.pushB43.setObjectName(u"pushB43")
        sizePolicy.setHeightForWidth(self.pushB43.sizePolicy().hasHeightForWidth())
        self.pushB43.setSizePolicy(sizePolicy)
        self.pushB43.setMinimumSize(QSize(25, 25))
        self.pushB43.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB43, 4, 8, 1, 1)

        self.pushB59 = CountingButton(Dialog)
        self.pushB59.setObjectName(u"pushB59")
        sizePolicy.setHeightForWidth(self.pushB59.sizePolicy().hasHeightForWidth())
        self.pushB59.setSizePolicy(sizePolicy)
        self.pushB59.setMinimumSize(QSize(25, 25))
        self.pushB59.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB59, 8, 6, 1, 1)

        self.pushB76 = CountingButton(Dialog)
        self.pushB76.setObjectName(u"pushB76")
        sizePolicy.setHeightForWidth(self.pushB76.sizePolicy().hasHeightForWidth())
        self.pushB76.setSizePolicy(sizePolicy)
        self.pushB76.setMinimumSize(QSize(25, 25))
        self.pushB76.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB76, 5, 9, 1, 1)

        self.pushB20 = CountingButton(Dialog)
        self.pushB20.setObjectName(u"pushB20")
        sizePolicy.setHeightForWidth(self.pushB20.sizePolicy().hasHeightForWidth())
        self.pushB20.setSizePolicy(sizePolicy)
        self.pushB20.setMinimumSize(QSize(25, 25))
        self.pushB20.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB20, 3, 3, 1, 1)

        self.pushB40 = CountingButton(Dialog)
        self.pushB40.setObjectName(u"pushB40")
        sizePolicy.setHeightForWidth(self.pushB40.sizePolicy().hasHeightForWidth())
        self.pushB40.setSizePolicy(sizePolicy)
        self.pushB40.setMinimumSize(QSize(25, 25))
        self.pushB40.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB40, 4, 5, 1, 1)

        self.pushB65 = CountingButton(Dialog)
        self.pushB65.setObjectName(u"pushB65")
        sizePolicy.setHeightForWidth(self.pushB65.sizePolicy().hasHeightForWidth())
        self.pushB65.setSizePolicy(sizePolicy)
        self.pushB65.setMinimumSize(QSize(25, 25))
        self.pushB65.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB65, 8, 12, 1, 1)

        self.pushB89 = CountingButton(Dialog)
        self.pushB89.setObjectName(u"pushB89")
        sizePolicy.setHeightForWidth(self.pushB89.sizePolicy().hasHeightForWidth())
        self.pushB89.setSizePolicy(sizePolicy)
        self.pushB89.setMinimumSize(QSize(25, 25))
        self.pushB89.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB89, 9, 4, 1, 1)

        self.pushB81 = CountingButton(Dialog)
        self.pushB81.setObjectName(u"pushB81")
        sizePolicy.setHeightForWidth(self.pushB81.sizePolicy().hasHeightForWidth())
        self.pushB81.setSizePolicy(sizePolicy)
        self.pushB81.setMinimumSize(QSize(25, 25))
        self.pushB81.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB81, 5, 14, 1, 1)

        self.pushB52 = CountingButton(Dialog)
        self.pushB52.setObjectName(u"pushB52")
        sizePolicy.setHeightForWidth(self.pushB52.sizePolicy().hasHeightForWidth())
        self.pushB52.setSizePolicy(sizePolicy)
        self.pushB52.setMinimumSize(QSize(25, 25))
        self.pushB52.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB52, 4, 17, 1, 1)

        self.pushB32 = CountingButton(Dialog)
        self.pushB32.setObjectName(u"pushB32")
        sizePolicy.setHeightForWidth(self.pushB32.sizePolicy().hasHeightForWidth())
        self.pushB32.setSizePolicy(sizePolicy)
        self.pushB32.setMinimumSize(QSize(25, 25))
        self.pushB32.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB32, 3, 15, 1, 1)

        self.pushB8 = CountingButton(Dialog)
        self.pushB8.setObjectName(u"pushB8")
        sizePolicy.setHeightForWidth(self.pushB8.sizePolicy().hasHeightForWidth())
        self.pushB8.setSizePolicy(sizePolicy)
        self.pushB8.setMinimumSize(QSize(25, 25))
        self.pushB8.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB8, 1, 17, 1, 1)

        self.pushB117 = CountingButton(Dialog)
        self.pushB117.setObjectName(u"pushB117")
        sizePolicy.setHeightForWidth(self.pushB117.sizePolicy().hasHeightForWidth())
        self.pushB117.setSizePolicy(sizePolicy)
        self.pushB117.setMinimumSize(QSize(25, 25))
        self.pushB117.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB117, 6, 18, 1, 1)

        self.pushB84 = CountingButton(Dialog)
        self.pushB84.setObjectName(u"pushB84")
        sizePolicy.setHeightForWidth(self.pushB84.sizePolicy().hasHeightForWidth())
        self.pushB84.setSizePolicy(sizePolicy)
        self.pushB84.setMinimumSize(QSize(25, 25))
        self.pushB84.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB84, 5, 17, 1, 1)

        self.pushB21 = CountingButton(Dialog)
        self.pushB21.setObjectName(u"pushB21")
        sizePolicy.setHeightForWidth(self.pushB21.sizePolicy().hasHeightForWidth())
        self.pushB21.setSizePolicy(sizePolicy)
        self.pushB21.setMinimumSize(QSize(25, 25))
        self.pushB21.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB21, 3, 4, 1, 1)

        self.pushB9 = CountingButton(Dialog)
        self.pushB9.setObjectName(u"pushB9")
        sizePolicy.setHeightForWidth(self.pushB9.sizePolicy().hasHeightForWidth())
        self.pushB9.setSizePolicy(sizePolicy)
        self.pushB9.setMinimumSize(QSize(25, 25))
        self.pushB9.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB9, 1, 18, 1, 1)

        self.pushB14 = CountingButton(Dialog)
        self.pushB14.setObjectName(u"pushB14")
        sizePolicy.setHeightForWidth(self.pushB14.sizePolicy().hasHeightForWidth())
        self.pushB14.setSizePolicy(sizePolicy)
        self.pushB14.setMinimumSize(QSize(25, 25))
        self.pushB14.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB14, 2, 15, 1, 1)

        self.pushB26 = CountingButton(Dialog)
        self.pushB26.setObjectName(u"pushB26")
        sizePolicy.setHeightForWidth(self.pushB26.sizePolicy().hasHeightForWidth())
        self.pushB26.setSizePolicy(sizePolicy)
        self.pushB26.setMinimumSize(QSize(25, 25))
        self.pushB26.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB26, 3, 9, 1, 1)

        self.pushB33 = CountingButton(Dialog)
        self.pushB33.setObjectName(u"pushB33")
        sizePolicy.setHeightForWidth(self.pushB33.sizePolicy().hasHeightForWidth())
        self.pushB33.setSizePolicy(sizePolicy)
        self.pushB33.setMinimumSize(QSize(25, 25))
        self.pushB33.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB33, 3, 16, 1, 1)

        self.pushB31 = CountingButton(Dialog)
        self.pushB31.setObjectName(u"pushB31")
        sizePolicy.setHeightForWidth(self.pushB31.sizePolicy().hasHeightForWidth())
        self.pushB31.setSizePolicy(sizePolicy)
        self.pushB31.setMinimumSize(QSize(25, 25))
        self.pushB31.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB31, 3, 14, 1, 1)

        self.pushB17 = CountingButton(Dialog)
        self.pushB17.setObjectName(u"pushB17")
        sizePolicy.setHeightForWidth(self.pushB17.sizePolicy().hasHeightForWidth())
        self.pushB17.setSizePolicy(sizePolicy)
        self.pushB17.setMinimumSize(QSize(25, 25))
        self.pushB17.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB17, 2, 18, 1, 1)

        self.pushB109 = CountingButton(Dialog)
        self.pushB109.setObjectName(u"pushB109")
        sizePolicy.setHeightForWidth(self.pushB109.sizePolicy().hasHeightForWidth())
        self.pushB109.setSizePolicy(sizePolicy)
        self.pushB109.setMinimumSize(QSize(25, 25))
        self.pushB109.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB109, 6, 10, 1, 1)

        self.pushB108 = CountingButton(Dialog)
        self.pushB108.setObjectName(u"pushB108")
        sizePolicy.setHeightForWidth(self.pushB108.sizePolicy().hasHeightForWidth())
        self.pushB108.setSizePolicy(sizePolicy)
        self.pushB108.setMinimumSize(QSize(25, 25))
        self.pushB108.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB108, 6, 9, 1, 1)

        self.pushB3 = CountingButton(Dialog)
        self.pushB3.setObjectName(u"pushB3")
        sizePolicy.setHeightForWidth(self.pushB3.sizePolicy().hasHeightForWidth())
        self.pushB3.setSizePolicy(sizePolicy)
        self.pushB3.setMinimumSize(QSize(25, 25))
        self.pushB3.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB3, 1, 2, 1, 1)

        self.pushB78 = CountingButton(Dialog)
        self.pushB78.setObjectName(u"pushB78")
        sizePolicy.setHeightForWidth(self.pushB78.sizePolicy().hasHeightForWidth())
        self.pushB78.setSizePolicy(sizePolicy)
        self.pushB78.setMinimumSize(QSize(25, 25))
        self.pushB78.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB78, 5, 11, 1, 1)

        self.pushB105 = CountingButton(Dialog)
        self.pushB105.setObjectName(u"pushB105")
        sizePolicy.setHeightForWidth(self.pushB105.sizePolicy().hasHeightForWidth())
        self.pushB105.setSizePolicy(sizePolicy)
        self.pushB105.setMinimumSize(QSize(25, 25))
        self.pushB105.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB105, 6, 6, 1, 1)

        self.pushB34 = CountingButton(Dialog)
        self.pushB34.setObjectName(u"pushB34")
        sizePolicy.setHeightForWidth(self.pushB34.sizePolicy().hasHeightForWidth())
        self.pushB34.setSizePolicy(sizePolicy)
        self.pushB34.setMinimumSize(QSize(25, 25))
        self.pushB34.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB34, 3, 17, 1, 1)

        self.pushB87 = CountingButton(Dialog)
        self.pushB87.setObjectName(u"pushB87")
        sizePolicy.setHeightForWidth(self.pushB87.sizePolicy().hasHeightForWidth())
        self.pushB87.setSizePolicy(sizePolicy)
        self.pushB87.setMinimumSize(QSize(25, 25))
        self.pushB87.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB87, 6, 2, 1, 1)

        self.pushB23 = CountingButton(Dialog)
        self.pushB23.setObjectName(u"pushB23")
        sizePolicy.setHeightForWidth(self.pushB23.sizePolicy().hasHeightForWidth())
        self.pushB23.setSizePolicy(sizePolicy)
        self.pushB23.setMinimumSize(QSize(25, 25))
        self.pushB23.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB23, 3, 6, 1, 1)

        self.pushB4 = CountingButton(Dialog)
        self.pushB4.setObjectName(u"pushB4")
        sizePolicy.setHeightForWidth(self.pushB4.sizePolicy().hasHeightForWidth())
        self.pushB4.setSizePolicy(sizePolicy)
        self.pushB4.setMinimumSize(QSize(25, 25))
        self.pushB4.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB4, 1, 13, 1, 1)

        self.pushB83 = CountingButton(Dialog)
        self.pushB83.setObjectName(u"pushB83")
        sizePolicy.setHeightForWidth(self.pushB83.sizePolicy().hasHeightForWidth())
        self.pushB83.setSizePolicy(sizePolicy)
        self.pushB83.setMinimumSize(QSize(25, 25))
        self.pushB83.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB83, 5, 16, 1, 1)

        self.pushB115 = CountingButton(Dialog)
        self.pushB115.setObjectName(u"pushB115")
        sizePolicy.setHeightForWidth(self.pushB115.sizePolicy().hasHeightForWidth())
        self.pushB115.setSizePolicy(sizePolicy)
        self.pushB115.setMinimumSize(QSize(25, 25))
        self.pushB115.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB115, 6, 16, 1, 1)

        self.pushB44 = CountingButton(Dialog)
        self.pushB44.setObjectName(u"pushB44")
        sizePolicy.setHeightForWidth(self.pushB44.sizePolicy().hasHeightForWidth())
        self.pushB44.setSizePolicy(sizePolicy)
        self.pushB44.setMinimumSize(QSize(25, 25))
        self.pushB44.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB44, 4, 9, 1, 1)

        self.pushB27 = CountingButton(Dialog)
        self.pushB27.setObjectName(u"pushB27")
        sizePolicy.setHeightForWidth(self.pushB27.sizePolicy().hasHeightForWidth())
        self.pushB27.setSizePolicy(sizePolicy)
        self.pushB27.setMinimumSize(QSize(25, 25))
        self.pushB27.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB27, 3, 10, 1, 1)

        self.pushB92 = CountingButton(Dialog)
        self.pushB92.setObjectName(u"pushB92")
        sizePolicy.setHeightForWidth(self.pushB92.sizePolicy().hasHeightForWidth())
        self.pushB92.setSizePolicy(sizePolicy)
        self.pushB92.setMinimumSize(QSize(25, 25))
        self.pushB92.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB92, 9, 7, 1, 1)

        self.pushB61 = CountingButton(Dialog)
        self.pushB61.setObjectName(u"pushB61")
        sizePolicy.setHeightForWidth(self.pushB61.sizePolicy().hasHeightForWidth())
        self.pushB61.setSizePolicy(sizePolicy)
        self.pushB61.setMinimumSize(QSize(25, 25))
        self.pushB61.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB61, 8, 8, 1, 1)

        self.pushB41 = CountingButton(Dialog)
        self.pushB41.setObjectName(u"pushB41")
        sizePolicy.setHeightForWidth(self.pushB41.sizePolicy().hasHeightForWidth())
        self.pushB41.setSizePolicy(sizePolicy)
        self.pushB41.setMinimumSize(QSize(25, 25))
        self.pushB41.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB41, 4, 6, 1, 1)

        self.pushB57 = CountingButton(Dialog)
        self.pushB57.setObjectName(u"pushB57")
        sizePolicy.setHeightForWidth(self.pushB57.sizePolicy().hasHeightForWidth())
        self.pushB57.setSizePolicy(sizePolicy)
        self.pushB57.setMinimumSize(QSize(25, 25))
        self.pushB57.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB57, 8, 4, 1, 1)

        self.pushB95 = CountingButton(Dialog)
        self.pushB95.setObjectName(u"pushB95")
        sizePolicy.setHeightForWidth(self.pushB95.sizePolicy().hasHeightForWidth())
        self.pushB95.setSizePolicy(sizePolicy)
        self.pushB95.setMinimumSize(QSize(25, 25))
        self.pushB95.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB95, 9, 10, 1, 1)

        self.pushB97 = CountingButton(Dialog)
        self.pushB97.setObjectName(u"pushB97")
        sizePolicy.setHeightForWidth(self.pushB97.sizePolicy().hasHeightForWidth())
        self.pushB97.setSizePolicy(sizePolicy)
        self.pushB97.setMinimumSize(QSize(25, 25))
        self.pushB97.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB97, 9, 12, 1, 1)

        self.pushB99 = CountingButton(Dialog)
        self.pushB99.setObjectName(u"pushB99")
        sizePolicy.setHeightForWidth(self.pushB99.sizePolicy().hasHeightForWidth())
        self.pushB99.setSizePolicy(sizePolicy)
        self.pushB99.setMinimumSize(QSize(25, 25))
        self.pushB99.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB99, 9, 14, 1, 1)

        self.pushB47 = CountingButton(Dialog)
        self.pushB47.setObjectName(u"pushB47")
        sizePolicy.setHeightForWidth(self.pushB47.sizePolicy().hasHeightForWidth())
        self.pushB47.setSizePolicy(sizePolicy)
        self.pushB47.setMinimumSize(QSize(25, 25))
        self.pushB47.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB47, 4, 12, 1, 1)

        self.pushB106 = CountingButton(Dialog)
        self.pushB106.setObjectName(u"pushB106")
        sizePolicy.setHeightForWidth(self.pushB106.sizePolicy().hasHeightForWidth())
        self.pushB106.setSizePolicy(sizePolicy)
        self.pushB106.setMinimumSize(QSize(25, 25))
        self.pushB106.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB106, 6, 7, 1, 1)

        self.pushB71 = CountingButton(Dialog)
        self.pushB71.setObjectName(u"pushB71")
        sizePolicy.setHeightForWidth(self.pushB71.sizePolicy().hasHeightForWidth())
        self.pushB71.setSizePolicy(sizePolicy)
        self.pushB71.setMinimumSize(QSize(25, 25))
        self.pushB71.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB71, 5, 4, 1, 1)

        self.pushB58 = CountingButton(Dialog)
        self.pushB58.setObjectName(u"pushB58")
        sizePolicy.setHeightForWidth(self.pushB58.sizePolicy().hasHeightForWidth())
        self.pushB58.setSizePolicy(sizePolicy)
        self.pushB58.setMinimumSize(QSize(25, 25))
        self.pushB58.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB58, 8, 5, 1, 1)

        self.pushB104 = CountingButton(Dialog)
        self.pushB104.setObjectName(u"pushB104")
        sizePolicy.setHeightForWidth(self.pushB104.sizePolicy().hasHeightForWidth())
        self.pushB104.setSizePolicy(sizePolicy)
        self.pushB104.setMinimumSize(QSize(25, 25))
        self.pushB104.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB104, 6, 5, 1, 1)

        self.pushB68 = CountingButton(Dialog)
        self.pushB68.setObjectName(u"pushB68")
        sizePolicy.setHeightForWidth(self.pushB68.sizePolicy().hasHeightForWidth())
        self.pushB68.setSizePolicy(sizePolicy)
        self.pushB68.setMinimumSize(QSize(25, 25))
        self.pushB68.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB68, 8, 15, 1, 1)

        self.pushB15 = CountingButton(Dialog)
        self.pushB15.setObjectName(u"pushB15")
        sizePolicy.setHeightForWidth(self.pushB15.sizePolicy().hasHeightForWidth())
        self.pushB15.setSizePolicy(sizePolicy)
        self.pushB15.setMinimumSize(QSize(25, 25))
        self.pushB15.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB15, 2, 16, 1, 1)

        self.pushB90 = CountingButton(Dialog)
        self.pushB90.setObjectName(u"pushB90")
        sizePolicy.setHeightForWidth(self.pushB90.sizePolicy().hasHeightForWidth())
        self.pushB90.setSizePolicy(sizePolicy)
        self.pushB90.setMinimumSize(QSize(25, 25))
        self.pushB90.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB90, 9, 5, 1, 1)

        self.pushB112 = CountingButton(Dialog)
        self.pushB112.setObjectName(u"pushB112")
        sizePolicy.setHeightForWidth(self.pushB112.sizePolicy().hasHeightForWidth())
        self.pushB112.setSizePolicy(sizePolicy)
        self.pushB112.setMinimumSize(QSize(25, 25))
        self.pushB112.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB112, 6, 13, 1, 1)

        self.pushB94 = CountingButton(Dialog)
        self.pushB94.setObjectName(u"pushB94")
        sizePolicy.setHeightForWidth(self.pushB94.sizePolicy().hasHeightForWidth())
        self.pushB94.setSizePolicy(sizePolicy)
        self.pushB94.setMinimumSize(QSize(25, 25))
        self.pushB94.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB94, 9, 9, 1, 1)

        self.pushB77 = CountingButton(Dialog)
        self.pushB77.setObjectName(u"pushB77")
        sizePolicy.setHeightForWidth(self.pushB77.sizePolicy().hasHeightForWidth())
        self.pushB77.setSizePolicy(sizePolicy)
        self.pushB77.setMinimumSize(QSize(25, 25))
        self.pushB77.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB77, 5, 10, 1, 1)

        self.pushB49 = CountingButton(Dialog)
        self.pushB49.setObjectName(u"pushB49")
        sizePolicy.setHeightForWidth(self.pushB49.sizePolicy().hasHeightForWidth())
        self.pushB49.setSizePolicy(sizePolicy)
        self.pushB49.setMinimumSize(QSize(25, 25))
        self.pushB49.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB49, 4, 14, 1, 1)

        self.pushB45 = CountingButton(Dialog)
        self.pushB45.setObjectName(u"pushB45")
        sizePolicy.setHeightForWidth(self.pushB45.sizePolicy().hasHeightForWidth())
        self.pushB45.setSizePolicy(sizePolicy)
        self.pushB45.setMinimumSize(QSize(25, 25))
        self.pushB45.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB45, 4, 10, 1, 1)

        self.pushB7 = CountingButton(Dialog)
        self.pushB7.setObjectName(u"pushB7")
        sizePolicy.setHeightForWidth(self.pushB7.sizePolicy().hasHeightForWidth())
        self.pushB7.setSizePolicy(sizePolicy)
        self.pushB7.setMinimumSize(QSize(25, 25))
        self.pushB7.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB7, 1, 16, 1, 1)

        self.pushB86 = CountingButton(Dialog)
        self.pushB86.setObjectName(u"pushB86")
        sizePolicy.setHeightForWidth(self.pushB86.sizePolicy().hasHeightForWidth())
        self.pushB86.setSizePolicy(sizePolicy)
        self.pushB86.setMinimumSize(QSize(25, 25))
        self.pushB86.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB86, 6, 1, 1, 1)

        self.pushB46 = CountingButton(Dialog)
        self.pushB46.setObjectName(u"pushB46")
        sizePolicy.setHeightForWidth(self.pushB46.sizePolicy().hasHeightForWidth())
        self.pushB46.setSizePolicy(sizePolicy)
        self.pushB46.setMinimumSize(QSize(25, 25))
        self.pushB46.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB46, 4, 11, 1, 1)

        self.pushB36 = CountingButton(Dialog)
        self.pushB36.setObjectName(u"pushB36")
        sizePolicy.setHeightForWidth(self.pushB36.sizePolicy().hasHeightForWidth())
        self.pushB36.setSizePolicy(sizePolicy)
        self.pushB36.setMinimumSize(QSize(25, 25))
        self.pushB36.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB36, 4, 1, 1, 1)

        self.pushB67 = CountingButton(Dialog)
        self.pushB67.setObjectName(u"pushB67")
        sizePolicy.setHeightForWidth(self.pushB67.sizePolicy().hasHeightForWidth())
        self.pushB67.setSizePolicy(sizePolicy)
        self.pushB67.setMinimumSize(QSize(25, 25))
        self.pushB67.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB67, 8, 14, 1, 1)

        self.pushB24 = CountingButton(Dialog)
        self.pushB24.setObjectName(u"pushB24")
        sizePolicy.setHeightForWidth(self.pushB24.sizePolicy().hasHeightForWidth())
        self.pushB24.setSizePolicy(sizePolicy)
        self.pushB24.setMinimumSize(QSize(25, 25))
        self.pushB24.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB24, 3, 7, 1, 1)

        self.pushB107 = CountingButton(Dialog)
        self.pushB107.setObjectName(u"pushB107")
        sizePolicy.setHeightForWidth(self.pushB107.sizePolicy().hasHeightForWidth())
        self.pushB107.setSizePolicy(sizePolicy)
        self.pushB107.setMinimumSize(QSize(25, 25))
        self.pushB107.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB107, 6, 8, 1, 1)

        self.pushB80 = CountingButton(Dialog)
        self.pushB80.setObjectName(u"pushB80")
        sizePolicy.setHeightForWidth(self.pushB80.sizePolicy().hasHeightForWidth())
        self.pushB80.setSizePolicy(sizePolicy)
        self.pushB80.setMinimumSize(QSize(25, 25))
        self.pushB80.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB80, 5, 13, 1, 1)

        self.pushB37 = CountingButton(Dialog)
        self.pushB37.setObjectName(u"pushB37")
        sizePolicy.setHeightForWidth(self.pushB37.sizePolicy().hasHeightForWidth())
        self.pushB37.setSizePolicy(sizePolicy)
        self.pushB37.setMinimumSize(QSize(25, 25))
        self.pushB37.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB37, 4, 2, 1, 1)

        self.pushB73 = CountingButton(Dialog)
        self.pushB73.setObjectName(u"pushB73")
        sizePolicy.setHeightForWidth(self.pushB73.sizePolicy().hasHeightForWidth())
        self.pushB73.setSizePolicy(sizePolicy)
        self.pushB73.setMinimumSize(QSize(25, 25))
        self.pushB73.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB73, 5, 6, 1, 1)

        self.pushB1 = CountingButton(Dialog)
        self.pushB1.setObjectName(u"pushB1")
        sizePolicy.setHeightForWidth(self.pushB1.sizePolicy().hasHeightForWidth())
        self.pushB1.setSizePolicy(sizePolicy)
        self.pushB1.setMinimumSize(QSize(25, 25))
        self.pushB1.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB1, 0, 18, 1, 1)

        self.pushB74 = CountingButton(Dialog)
        self.pushB74.setObjectName(u"pushB74")
        sizePolicy.setHeightForWidth(self.pushB74.sizePolicy().hasHeightForWidth())
        self.pushB74.setSizePolicy(sizePolicy)
        self.pushB74.setMinimumSize(QSize(25, 25))
        self.pushB74.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB74, 5, 7, 1, 1)

        self.pushB102 = CountingButton(Dialog)
        self.pushB102.setObjectName(u"pushB102")
        sizePolicy.setHeightForWidth(self.pushB102.sizePolicy().hasHeightForWidth())
        self.pushB102.setSizePolicy(sizePolicy)
        self.pushB102.setMinimumSize(QSize(25, 25))
        self.pushB102.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB102, 9, 17, 1, 1)

        self.pushB111 = CountingButton(Dialog)
        self.pushB111.setObjectName(u"pushB111")
        sizePolicy.setHeightForWidth(self.pushB111.sizePolicy().hasHeightForWidth())
        self.pushB111.setSizePolicy(sizePolicy)
        self.pushB111.setMinimumSize(QSize(25, 25))
        self.pushB111.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB111, 6, 12, 1, 1)

        self.pushB10 = CountingButton(Dialog)
        self.pushB10.setObjectName(u"pushB10")
        sizePolicy.setHeightForWidth(self.pushB10.sizePolicy().hasHeightForWidth())
        self.pushB10.setSizePolicy(sizePolicy)
        self.pushB10.setMinimumSize(QSize(25, 25))
        self.pushB10.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB10, 2, 1, 1, 1)

        self.pushB13 = CountingButton(Dialog)
        self.pushB13.setObjectName(u"pushB13")
        sizePolicy.setHeightForWidth(self.pushB13.sizePolicy().hasHeightForWidth())
        self.pushB13.setSizePolicy(sizePolicy)
        self.pushB13.setMinimumSize(QSize(25, 25))
        self.pushB13.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB13, 2, 14, 1, 1)

        self.pushB2 = CountingButton(Dialog)
        self.pushB2.setObjectName(u"pushB2")
        sizePolicy.setHeightForWidth(self.pushB2.sizePolicy().hasHeightForWidth())
        self.pushB2.setSizePolicy(sizePolicy)
        self.pushB2.setMinimumSize(QSize(25, 25))
        self.pushB2.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB2, 1, 1, 1, 1)

        self.pushB55 = CountingButton(Dialog)
        self.pushB55.setObjectName(u"pushB55")
        sizePolicy.setHeightForWidth(self.pushB55.sizePolicy().hasHeightForWidth())
        self.pushB55.setSizePolicy(sizePolicy)
        self.pushB55.setMinimumSize(QSize(25, 25))
        self.pushB55.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB55, 5, 2, 1, 1)

        self.pushB56 = CountingButton(Dialog)
        self.pushB56.setObjectName(u"pushB56")
        sizePolicy.setHeightForWidth(self.pushB56.sizePolicy().hasHeightForWidth())
        self.pushB56.setSizePolicy(sizePolicy)
        self.pushB56.setMinimumSize(QSize(25, 25))
        self.pushB56.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB56, 8, 3, 1, 1)

        self.pushB25 = CountingButton(Dialog)
        self.pushB25.setObjectName(u"pushB25")
        sizePolicy.setHeightForWidth(self.pushB25.sizePolicy().hasHeightForWidth())
        self.pushB25.setSizePolicy(sizePolicy)
        self.pushB25.setMinimumSize(QSize(25, 25))
        self.pushB25.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB25, 3, 8, 1, 1)

        self.pushB93 = CountingButton(Dialog)
        self.pushB93.setObjectName(u"pushB93")
        sizePolicy.setHeightForWidth(self.pushB93.sizePolicy().hasHeightForWidth())
        self.pushB93.setSizePolicy(sizePolicy)
        self.pushB93.setMinimumSize(QSize(25, 25))
        self.pushB93.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB93, 9, 8, 1, 1)

        self.pushB28 = CountingButton(Dialog)
        self.pushB28.setObjectName(u"pushB28")
        sizePolicy.setHeightForWidth(self.pushB28.sizePolicy().hasHeightForWidth())
        self.pushB28.setSizePolicy(sizePolicy)
        self.pushB28.setMinimumSize(QSize(25, 25))
        self.pushB28.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB28, 3, 11, 1, 1)

        self.pushB19 = CountingButton(Dialog)
        self.pushB19.setObjectName(u"pushB19")
        sizePolicy.setHeightForWidth(self.pushB19.sizePolicy().hasHeightForWidth())
        self.pushB19.setSizePolicy(sizePolicy)
        self.pushB19.setMinimumSize(QSize(25, 25))
        self.pushB19.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB19, 3, 2, 1, 1)

        self.pushB51 = CountingButton(Dialog)
        self.pushB51.setObjectName(u"pushB51")
        sizePolicy.setHeightForWidth(self.pushB51.sizePolicy().hasHeightForWidth())
        self.pushB51.setSizePolicy(sizePolicy)
        self.pushB51.setMinimumSize(QSize(25, 25))
        self.pushB51.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB51, 4, 16, 1, 1)

        self.pushB30 = CountingButton(Dialog)
        self.pushB30.setObjectName(u"pushB30")
        sizePolicy.setHeightForWidth(self.pushB30.sizePolicy().hasHeightForWidth())
        self.pushB30.setSizePolicy(sizePolicy)
        self.pushB30.setMinimumSize(QSize(25, 25))
        self.pushB30.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB30, 3, 13, 1, 1)

        self.pushB113 = CountingButton(Dialog)
        self.pushB113.setObjectName(u"pushB113")
        sizePolicy.setHeightForWidth(self.pushB113.sizePolicy().hasHeightForWidth())
        self.pushB113.setSizePolicy(sizePolicy)
        self.pushB113.setMinimumSize(QSize(25, 25))
        self.pushB113.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB113, 6, 14, 1, 1)

        self.pushB48 = CountingButton(Dialog)
        self.pushB48.setObjectName(u"pushB48")
        sizePolicy.setHeightForWidth(self.pushB48.sizePolicy().hasHeightForWidth())
        self.pushB48.setSizePolicy(sizePolicy)
        self.pushB48.setMinimumSize(QSize(25, 25))
        self.pushB48.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB48, 4, 13, 1, 1)

        self.pushB53 = CountingButton(Dialog)
        self.pushB53.setObjectName(u"pushB53")
        sizePolicy.setHeightForWidth(self.pushB53.sizePolicy().hasHeightForWidth())
        self.pushB53.setSizePolicy(sizePolicy)
        self.pushB53.setMinimumSize(QSize(25, 25))
        self.pushB53.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB53, 4, 18, 1, 1)

        self.pushB5 = CountingButton(Dialog)
        self.pushB5.setObjectName(u"pushB5")
        sizePolicy.setHeightForWidth(self.pushB5.sizePolicy().hasHeightForWidth())
        self.pushB5.setSizePolicy(sizePolicy)
        self.pushB5.setMinimumSize(QSize(25, 25))
        self.pushB5.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB5, 1, 14, 1, 1)

        self.pushB16 = CountingButton(Dialog)
        self.pushB16.setObjectName(u"pushB16")
        sizePolicy.setHeightForWidth(self.pushB16.sizePolicy().hasHeightForWidth())
        self.pushB16.setSizePolicy(sizePolicy)
        self.pushB16.setMinimumSize(QSize(25, 25))
        self.pushB16.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB16, 2, 17, 1, 1)

        self.pushB6 = CountingButton(Dialog)
        self.pushB6.setObjectName(u"pushB6")
        sizePolicy.setHeightForWidth(self.pushB6.sizePolicy().hasHeightForWidth())
        self.pushB6.setSizePolicy(sizePolicy)
        self.pushB6.setMinimumSize(QSize(25, 25))
        self.pushB6.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB6, 1, 15, 1, 1)

        self.pushB39 = CountingButton(Dialog)
        self.pushB39.setObjectName(u"pushB39")
        sizePolicy.setHeightForWidth(self.pushB39.sizePolicy().hasHeightForWidth())
        self.pushB39.setSizePolicy(sizePolicy)
        self.pushB39.setMinimumSize(QSize(25, 25))
        self.pushB39.setMaximumSize(QSize(25, 25))

        self.gridLayout.addWidget(self.pushB39, 4, 4, 1, 1)

        self.label_2 = QLabel(Dialog)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setMaximumSize(QSize(60, 16777215))

        self.gridLayout.addWidget(self.label_2, 7, 3, 1, 1)


        self.verticalLayout.addLayout(self.gridLayout)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setContentsMargins(4, 4, 4, 4)
        self.label = QLabel(Dialog)
        self.label.setObjectName(u"label")
        self.label.setMaximumSize(QSize(60, 16777215))

        self.horizontalLayout_2.addWidget(self.label)

        self.lineEdit = QLineEdit(Dialog)
        self.lineEdit.setObjectName(u"lineEdit")
        self.lineEdit.setEnabled(True)
        self.lineEdit.setMaximumSize(QSize(100, 16777215))
        self.lineEdit.setReadOnly(True)

        self.horizontalLayout_2.addWidget(self.lineEdit)

        self.pushButton_3 = QPushButton(Dialog)
        self.pushButton_3.setObjectName(u"pushButton_3")

        self.horizontalLayout_2.addWidget(self.pushButton_3)


        self.verticalLayout.addLayout(self.horizontalLayout_2)


        self.retranslateUi(Dialog)

        QMetaObject.connectSlotsByName(Dialog)
    # setupUi

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(QCoreApplication.translate("Dialog", u"debyetools - [define compound...]", None))
        self.pushB88.setText(QCoreApplication.translate("Dialog", u"Ac", None))
        self.pushB66.setText(QCoreApplication.translate("Dialog", u"Ho", None))
        self.pushB85.setText(QCoreApplication.translate("Dialog", u"Rn", None))
        self.pushB75.setText(QCoreApplication.translate("Dialog", u"Os", None))
        self.pushB101.setText(QCoreApplication.translate("Dialog", u"No", None))
        self.pushB110.setText(QCoreApplication.translate("Dialog", u"Rg", None))
        self.pushB82.setText(QCoreApplication.translate("Dialog", u"Bi", None))
        self.pushB70.setText(QCoreApplication.translate("Dialog", u"Lu", None))
        self.pushB116.setText(QCoreApplication.translate("Dialog", u"Ts", None))
        self.pushB72.setText(QCoreApplication.translate("Dialog", u"Ta", None))
        self.pushB114.setText(QCoreApplication.translate("Dialog", u"Mc", None))
        self.pushB22.setText(QCoreApplication.translate("Dialog", u"V", None))
        self.pushB103.setText(QCoreApplication.translate("Dialog", u"Rf", None))
        self.pushB35.setText(QCoreApplication.translate("Dialog", u"Kr", None))
        self.pushB12.setText(QCoreApplication.translate("Dialog", u"Al", None))
        self.pushB18.setText(QCoreApplication.translate("Dialog", u"K", None))
        self.pushB60.setText(QCoreApplication.translate("Dialog", u"Pm", None))
        self.pushB98.setText(QCoreApplication.translate("Dialog", u"Es", None))
        self.pushB100.setText(QCoreApplication.translate("Dialog", u"Md", None))
        self.pushB54.setText(QCoreApplication.translate("Dialog", u"Cs", None))
        self.pushB79.setText(QCoreApplication.translate("Dialog", u"Hg", None))
        self.pushB11.setText(QCoreApplication.translate("Dialog", u"Mg", None))
        self.pushB63.setText(QCoreApplication.translate("Dialog", u"Gd", None))
        self.pushB91.setText(QCoreApplication.translate("Dialog", u"U", None))
        self.pushB42.setText(QCoreApplication.translate("Dialog", u"Tc", None))
        self.pushB62.setText(QCoreApplication.translate("Dialog", u"Eu", None))
        self.pushB64.setText(QCoreApplication.translate("Dialog", u"Tb", None))
        self.pushB0.setText(QCoreApplication.translate("Dialog", u"H", None))
        self.pushB69.setText(QCoreApplication.translate("Dialog", u"Yb", None))
        self.pushB50.setText(QCoreApplication.translate("Dialog", u"Sb", None))
        self.pushB29.setText(QCoreApplication.translate("Dialog", u"Zn", None))
        self.pushB96.setText(QCoreApplication.translate("Dialog", u"Bk", None))
        self.pushB38.setText(QCoreApplication.translate("Dialog", u"Y", None))
        self.pushB43.setText(QCoreApplication.translate("Dialog", u"Ru", None))
        self.pushB59.setText(QCoreApplication.translate("Dialog", u"Nd", None))
        self.pushB76.setText(QCoreApplication.translate("Dialog", u"Ir", None))
        self.pushB20.setText(QCoreApplication.translate("Dialog", u"Sc", None))
        self.pushB40.setText(QCoreApplication.translate("Dialog", u"Nb", None))
        self.pushB65.setText(QCoreApplication.translate("Dialog", u"Dy", None))
        self.pushB89.setText(QCoreApplication.translate("Dialog", u"Th", None))
        self.pushB81.setText(QCoreApplication.translate("Dialog", u"Pb", None))
        self.pushB52.setText(QCoreApplication.translate("Dialog", u"I", None))
        self.pushB32.setText(QCoreApplication.translate("Dialog", u"As", None))
        self.pushB8.setText(QCoreApplication.translate("Dialog", u"F", None))
        self.pushB117.setText(QCoreApplication.translate("Dialog", u"Og", None))
        self.pushB84.setText(QCoreApplication.translate("Dialog", u"At", None))
        self.pushB21.setText(QCoreApplication.translate("Dialog", u"Ti", None))
        self.pushB9.setText(QCoreApplication.translate("Dialog", u"Ne", None))
        self.pushB14.setText(QCoreApplication.translate("Dialog", u"P", None))
        self.pushB26.setText(QCoreApplication.translate("Dialog", u"Co", None))
        self.pushB33.setText(QCoreApplication.translate("Dialog", u"Se", None))
        self.pushB31.setText(QCoreApplication.translate("Dialog", u"Ge", None))
        self.pushB17.setText(QCoreApplication.translate("Dialog", u"Ar", None))
        self.pushB109.setText(QCoreApplication.translate("Dialog", u"Ds", None))
        self.pushB108.setText(QCoreApplication.translate("Dialog", u"Mt", None))
        self.pushB3.setText(QCoreApplication.translate("Dialog", u"Be", None))
        self.pushB78.setText(QCoreApplication.translate("Dialog", u"Au", None))
        self.pushB105.setText(QCoreApplication.translate("Dialog", u"Sg", None))
        self.pushB34.setText(QCoreApplication.translate("Dialog", u"Br", None))
        self.pushB87.setText(QCoreApplication.translate("Dialog", u"Ra", None))
        self.pushB23.setText(QCoreApplication.translate("Dialog", u"Cr", None))
        self.pushB4.setText(QCoreApplication.translate("Dialog", u"B", None))
        self.pushB83.setText(QCoreApplication.translate("Dialog", u"Po", None))
        self.pushB115.setText(QCoreApplication.translate("Dialog", u"Lv", None))
        self.pushB44.setText(QCoreApplication.translate("Dialog", u"Rh", None))
        self.pushB27.setText(QCoreApplication.translate("Dialog", u"Ni", None))
        self.pushB92.setText(QCoreApplication.translate("Dialog", u"Np", None))
        self.pushB61.setText(QCoreApplication.translate("Dialog", u"Sm", None))
        self.pushB41.setText(QCoreApplication.translate("Dialog", u"Mo", None))
        self.pushB57.setText(QCoreApplication.translate("Dialog", u"Ce", None))
        self.pushB95.setText(QCoreApplication.translate("Dialog", u"Cm", None))
        self.pushB97.setText(QCoreApplication.translate("Dialog", u"Cf", None))
        self.pushB99.setText(QCoreApplication.translate("Dialog", u"Fm", None))
        self.pushB47.setText(QCoreApplication.translate("Dialog", u"Cd", None))
        self.pushB106.setText(QCoreApplication.translate("Dialog", u"Bh", None))
        self.pushB71.setText(QCoreApplication.translate("Dialog", u"Hf", None))
        self.pushB58.setText(QCoreApplication.translate("Dialog", u"Pr", None))
        self.pushB104.setText(QCoreApplication.translate("Dialog", u"Db", None))
        self.pushB68.setText(QCoreApplication.translate("Dialog", u"Tm", None))
        self.pushB15.setText(QCoreApplication.translate("Dialog", u"S", None))
        self.pushB90.setText(QCoreApplication.translate("Dialog", u"Pa", None))
        self.pushB112.setText(QCoreApplication.translate("Dialog", u"Nh", None))
        self.pushB94.setText(QCoreApplication.translate("Dialog", u"Am", None))
        self.pushB77.setText(QCoreApplication.translate("Dialog", u"Pt", None))
        self.pushB49.setText(QCoreApplication.translate("Dialog", u"Sn", None))
        self.pushB45.setText(QCoreApplication.translate("Dialog", u"Pd", None))
        self.pushB7.setText(QCoreApplication.translate("Dialog", u"O", None))
        self.pushB86.setText(QCoreApplication.translate("Dialog", u"Fr", None))
        self.pushB46.setText(QCoreApplication.translate("Dialog", u"Ag", None))
        self.pushB36.setText(QCoreApplication.translate("Dialog", u"Rb", None))
        self.pushB67.setText(QCoreApplication.translate("Dialog", u"Er", None))
        self.pushB24.setText(QCoreApplication.translate("Dialog", u"Mn", None))
        self.pushB107.setText(QCoreApplication.translate("Dialog", u"Hs", None))
        self.pushB80.setText(QCoreApplication.translate("Dialog", u"Tl", None))
        self.pushB37.setText(QCoreApplication.translate("Dialog", u"Sr", None))
        self.pushB73.setText(QCoreApplication.translate("Dialog", u"W", None))
        self.pushB1.setText(QCoreApplication.translate("Dialog", u"He", None))
        self.pushB74.setText(QCoreApplication.translate("Dialog", u"Re", None))
        self.pushB102.setText(QCoreApplication.translate("Dialog", u"Lr", None))
        self.pushB111.setText(QCoreApplication.translate("Dialog", u"Cn", None))
        self.pushB10.setText(QCoreApplication.translate("Dialog", u"Na", None))
        self.pushB13.setText(QCoreApplication.translate("Dialog", u"Si", None))
        self.pushB2.setText(QCoreApplication.translate("Dialog", u"Li", None))
        self.pushB55.setText(QCoreApplication.translate("Dialog", u"Ba", None))
        self.pushB56.setText(QCoreApplication.translate("Dialog", u"La", None))
        self.pushB25.setText(QCoreApplication.translate("Dialog", u"Fe", None))
        self.pushB93.setText(QCoreApplication.translate("Dialog", u"Pu", None))
        self.pushB28.setText(QCoreApplication.translate("Dialog", u"Cu", None))
        self.pushB19.setText(QCoreApplication.translate("Dialog", u"Ca", None))
        self.pushB51.setText(QCoreApplication.translate("Dialog", u"Te", None))
        self.pushB30.setText(QCoreApplication.translate("Dialog", u"Ga", None))
        self.pushB113.setText(QCoreApplication.translate("Dialog", u"Fl", None))
        self.pushB48.setText(QCoreApplication.translate("Dialog", u"In", None))
        self.pushB53.setText(QCoreApplication.translate("Dialog", u"Xe", None))
        self.pushB5.setText(QCoreApplication.translate("Dialog", u"C", None))
        self.pushB16.setText(QCoreApplication.translate("Dialog", u"Cl", None))
        self.pushB6.setText(QCoreApplication.translate("Dialog", u"N", None))
        self.pushB39.setText(QCoreApplication.translate("Dialog", u"Zr", None))
        self.label_2.setText("")
        self.label.setText(QCoreApplication.translate("Dialog", u"Formula:", None))
        self.pushButton_3.setText(QCoreApplication.translate("Dialog", u"OK", None))
    # retranslateUi




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'dialog_loadElastic.ui'
##
## Created by: Qt User Interface Compiler version 6.7.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QDialog, QHBoxLayout, QLabel,
    QLineEdit, QPushButton, QSizePolicy, QSpacerItem,
    QVBoxLayout, QWidget)

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        if not Dialog.objectName():
            Dialog.setObjectName(u"Dialog")
        Dialog.setWindowModality(Qt.WindowModality.WindowModal)
        Dialog.resize(400, 104)
        self.verticalLayout = QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.label = QLabel(Dialog)
        self.label.setObjectName(u"label")

        self.horizontalLayout_3.addWidget(self.label)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_3.addItem(self.horizontalSpacer_2)


        self.verticalLayout.addLayout(self.horizontalLayout_3)

        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.outcarpath = QLineEdit(Dialog)
        self.outcarpath.setObjectName(u"outcarpath")

        self.horizontalLayout.addWidget(self.outcarpath)

        self.browseoutcar = QPushButton(Dialog)
        self.browseoutcar.setObjectName(u"browseoutcar")

        self.horizontalLayout.addWidget(self.browseoutcar)


        self.verticalLayout.addLayout(self.horizontalLayout)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_2.addItem(self.horizontalSpacer)

        self.ok = QPushButton(Dialog)
        self.ok.setObjectName(u"ok")

        self.horizontalLayout_2.addWidget(self.ok)


        self.verticalLayout.addLayout(self.horizontalLayout_2)


        self.retranslateUi(Dialog)

        QMetaObject.connectSlotsByName(Dialog)
    # setupUi

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(QCoreApplication.translate("Dialog", u"debyetools - [select OUTCAR..]", None))
        self.label.setText(QCoreApplication.translate("Dialog", u"OUTCAR:", None))
        self.outcarpath.setText(QCoreApplication.translate("Dialog", u"./OUTCAR", None))
        self.browseoutcar.setText(QCoreApplication.translate("Dialog", u"Browse", None))
        self.ok.setText(QCoreApplication.translate("Dialog", u"OK", None))
    # retranslateUi




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'dialog_calculateNu.ui'
##
## Created by: Qt User Interface Compiler version 6.7.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QHBoxLayout, QLabel, QLineEdit,
    QPushButton, QSizePolicy, QSpacerItem, QTextEdit,
    QVBoxLayout, QWidget)

class Ui_Form(object):
    def setupUi(self, Form):
        if not Form.objectName():
            Form.setObjectName(u"Form")
        Form.setWindowModality(Qt.WindowModality.WindowModal)
        Form.resize(636, 190)
        self.verticalLayout = QVBoxLayout(Form)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout_6 = QHBoxLayout()
        self.horizontalLayout_6.setSpacing(2)
        self.horizontalLayout_6.setObjectName(u"horizontalLayout_6")
        self.verticalLayout_3 = QVBoxLayout()
        self.verticalLayout_3.setSpacing(2)
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.label_7 = QLabel(Form)
        self.label_7.setObjectName(u"label_7")

        self.verticalLayout_3.addWidget(self.label_7)

        self.elastic_constants = QTextEdit(Form)
        self.elastic_constants.setObjectName(u"elastic_constants")
        self.elastic_constants.setMinimumSize(QSize(200, 0))

        self.verticalLayout_3.addWidget(self.elastic_constants)


        self.horizontalLayout_6.addLayout(self.verticalLayout_3)

        self.verticalLayout_4 = QVBoxLayout()
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName(u"verticalLayout_4")
        self.verticalLayout_4.setContentsMargins(-1, 0, -1, -1)
        self.label = QLabel(Form)
        self.label.setObjectName(u"label")

        self.verticalLayout_4.addWidget(self.label)

        self.horizontalLayout_5 = QHBoxLayout()
        self.horizontalLayout_5.setSpacing(2)
        self.horizontalLayout_5.setObjectName(u"horizontalLayout_5")
        self.verticalLayout_13 = QVBoxLayout()
        self.verticalLayout_13.setSpacing(2)
        self.verticalLayout_13.setObjectName(u"verticalLayout_13")
        self.verticalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.label_9 = QLabel(Form)
        self.label_9.setObjectName(u"label_9")
        self.label_9.setMinimumSize(QSize(0, 22))
        self.label_9.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_13.addWidget(self.label_9)

        self.label_10 = QLabel(Form)
        self.label_10.setObjectName(u"label_10")
        self.label_10.setMinimumSize(QSize(0, 22))
        self.label_10.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_13.addWidget(self.label_10)

        self.label_11 = QLabel(Form)
        self.label_11.setObjectName(u"label_11")
        self.label_11.setMinimumSize(QSize(0, 22))
        self.label_11.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_13.addWidget(self.label_11)

        self.label_15 = QLabel(Form)
        self.label_15.setObjectName(u"label_15")
        self.label_15.setMinimumSize(QSize(0, 22))
        self.label_15.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_13.addWidget(self.label_15)

        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_13.addItem(self.verticalSpacer)


        self.horizontalLayout_5.addLayout(self.verticalLayout_13)

        self.verticalLayout_5 = QVBoxLayout()
        self.verticalLayout_5.setSpacing(2)
        self.verticalLayout_5.setObjectName(u"verticalLayout_5")
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.lineEdit_5 = QLineEdit(Form)
        self.lineEdit_5.setObjectName(u"lineEdit_5")
        self.lineEdit_5.setMinimumSize(QSize(0, 22))
        self.lineEdit_5.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_5.addWidget(self.lineEdit_5)

        self.lineEdit_4 = QLineEdit(Form)
        self.lineEdit_4.setObjectName(u"lineEdit_4")
        self.lineEdit_4.setMinimumSize(QSize(0, 22))
        self.lineEdit_4.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_5.addWidget(self.lineEdit_4)

        self.lineEdit_6 = QLineEdit(Form)
        self.lineEdit_6.setObjectName(u"lineEdit_6")
        self.lineEdit_6.setMinimumSize(QSize(0, 22))
        self.lineEdit_6.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_5.addWidget(self.lineEdit_6)

        self.lineEdit_10 = QLineEdit(Form)
        self.lineEdit_10.setObjectName(u"lineEdit_10")
        self.lineEdit_10.setMinimumSize(QSize(0, 22))
        self.lineEdit_10.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_5.addWidget(self.lineEdit_10)

        self.verticalSpacer_2 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_5.addItem(self.verticalSpacer_2)


        self.horizontalLayout_5.addLayout(self.verticalLayout_5)

        self.verticalLayout_11 = QVBoxLayout()
        self.verticalLayout_11.setSpacing(2)
        self.verticalLayout_11.setObjectName(u"verticalLayout_11")
        self.verticalLayout_11.setContentsMargins(0, 0, 0, 0)
        self.label_20 = QLabel(Form)
        self.label_20.setObjectName(u"label_20")
        self.label_20.setMinimumSize(QSize(0, 22))
        self.label_20.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_11.addWidget(self.label_20)

        self.label_23 = QLabel(Form)
        self.label_23.setObjectName(u"label_23")
        self.label_23.setMinimumSize(QSize(0, 22))
        self.label_23.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_11.addWidget(self.label_23)

        self.label_22 = QLabel(Form)
        self.label_22.setObjectName(u"label_22")
        self.label_22.setMinimumSize(QSize(0, 22))
        self.label_22.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_11.addWidget(self.label_22)

        self.label_21 = QLabel(Form)
        self.label_21.setObjectName(u"label_21")
        self.label_21.setMinimumSize(QSize(0, 22))
        self.label_21.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_11.addWidget(self.label_21)

        self.verticalSpacer_3 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_11.addItem(self.verticalSpacer_3)


        self.horizontalLayout_5.addLayout(self.verticalLayout_11)

        self.verticalLayout_7 = QVBoxLayout()
        self.verticalLayout_7.setSpacing(2)
        self.verticalLayout_7.setObjectName(u"verticalLayout_7")
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.label_12 = QLabel(Form)
        self.label_12.setObjectName(u"label_12")
        self.label_12.setMinimumSize(QSize(0, 22))
        self.label_12.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_7.addWidget(self.label_12)

        self.label_13 = QLabel(Form)
        self.label_13.setObjectName(u"label_13")
        self.label_13.setMinimumSize(QSize(0, 22))
        self.label_13.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_7.addWidget(self.label_13)

        self.label_14 = QLabel(Form)
        self.label_14.setObjectName(u"label_14")
        self.label_14.setMinimumSize(QSize(0, 22))
        self.label_14.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_7.addWidget(self.label_14)

        self.label_8 = QLabel(Form)
        self.label_8.setObjectName(u"label_8")
        self.label_8.setMinimumSize(QSize(0, 22))
        self.label_8.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_7.addWidget(self.label_8)

        self.verticalSpacer_4 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_7.addItem(self.verticalSpacer_4)


        self.horizontalLayout_5.addLayout(self.verticalLayout_7)

        self.verticalLayout_10 = QVBoxLayout()
        self.verticalLayout_10.setSpacing(2)
        self.verticalLayout_10.setObjectName(u"verticalLayout_10")
        self.verticalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.lineEdit_9 = QLineEdit(Form)
        self.lineEdit_9.setObjectName(u"lineEdit_9")
        self.lineEdit_9.setMinimumSize(QSize(0, 22))
        self.lineEdit_9.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_10.addWidget(self.lineEdit_9)

        self.lineEdit_8 = QLineEdit(Form)
        self.lineEdit_8.setObjectName(u"lineEdit_8")
        self.lineEdit_8.setMinimumSize(QSize(0, 22))
        self.lineEdit_8.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_10.addWidget(self.lineEdit_8)

        self.lineEdit_7 = QLineEdit(Form)
        self.lineEdit_7.setObjectName(u"lineEdit_7")
        self.lineEdit_7.setMinimumSize(QSize(0, 22))
        self.lineEdit_7.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_10.addWidget(self.lineEdit_7)

        self.lineEdit_3 = QLineEdit(Form)
        self.lineEdit_3.setObjectName(u"lineEdit_3")
        self.lineEdit_3.setMinimumSize(QSize(0, 22))
        self.lineEdit_3.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_10.addWidget(self.lineEdit_3)

        self.verticalSpacer_5 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_10.addItem(self.verticalSpacer_5)


        self.horizontalLayout_5.addLayout(self.verticalLayout_10)

        self.verticalLayout_6 = QVBoxLayout()
        self.verticalLayout_6.setSpacing(2)
        self.verticalLayout_6.setObjectName(u"verticalLayout_6")
        self.verticalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.label_16 = QLabel(Form)
        self.label_16.setObjectName(u"label_16")
        self.label_16.setMinimumSize(QSize(0, 22))
        self.label_16.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_6.addWidget(self.label_16)

        self.label_17 = QLabel(Form)
        self.label_17.setObjectName(u"label_17")
        self.label_17.setMinimumSize(QSize(0, 22))
        self.label_17.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_6.addWidget(self.label_17)

        self.label_18 = QLabel(Form)
        self.label_18.setObjectName(u"label_18")
        self.label_18.setMinimumSize(QSize(0, 22))
        self.label_18.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_6.addWidget(self.label_18)

        self.label_19 = QLabel(Form)
        self.label_19.setObjectName(u"label_19")
        self.label_19.setMinimumSize(QSize(0, 22))
        self.label_19.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_6.addWidget(self.label_19)

        self.pushMore = QPushButton(Form)
        self.pushMore.setObjectName(u"pushMore")

        self.verticalLayout_6.addWidget(self.pushMore)

        self.verticalSpacer_6 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_6.addItem(self.verticalSpacer_6)


        self.horizontalLayout_5.addLayout(self.verticalLayout_6)


        self.verticalLayout_4.addLayout(self.horizontalLayout_5)

        self.horizontalLayout_7 = QHBoxLayout()
        self.horizontalLayout_7.setObjectName(u"horizontalLayout_7")
        self.horizontalLayout_7.setContentsMargins(0, 0, 2, 0)
        self.pushLoadElastic = QPushButton(Form)
        self.pushLoadElastic.setObjectName(u"pushLoadElastic")

        self.horizontalLayout_7.addWidget(self.pushLoadElastic)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_7.addItem(self.horizontalSpacer_2)

        self.pushButton_2 = QPushButton(Form)
        self.pushButton_2.setObjectName(u"pushButton_2")

        self.horizontalLayout_7.addWidget(self.pushButton_2)

        self.pushSave = QPushButton(Form)
        self.pushSave.setObjectName(u"pushSave")

        self.horizontalLayout_7.addWidget(self.pushSave)


        self.verticalLayout_4.addLayout(self.horizontalLayout_7)


        self.horizontalLayout_6.addLayout(self.verticalLayout_4)


        self.verticalLayout.addLayout(self.horizontalLayout_6)


        self.retranslateUi(Form)

        QMetaObject.connectSlotsByName(Form)
    # setupUi

    def retranslateUi(self, Form):
        Form.setWindowTitle(QCoreApplication.translate("Form", u"debyetools - [elastic properties]", None))
        self.label_7.setText(QCoreApplication.translate("Form", u"Stiffness Tensor (GPa):", None))
        self.elastic_constants.setHtml(QCoreApplication.translate("Form", u"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Segoe UI'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>", None))
        self.label.setText(QCoreApplication.translate("Form", u"Average properties:", None))
        self.label_9.setText(QCoreApplication.translate("Form", u"B (Voigt):", None))
        self.label_10.setText(QCoreApplication.translate("Form", u"B (Reuss):", None))
        self.label_11.setText(QCoreApplication.translate("Form", u"B (Voigt-Reuss-Hill):", None))
        self.label_15.setText(QCoreApplication.translate("Form", u"Universal anisotrpy:", None))
        self.lineEdit_5.setText("")
        self.lineEdit_4.setText("")
        self.lineEdit_6.setText("")
        self.lineEdit_10.setText("")
        self.label_20.setText(QCoreApplication.translate("Form", u"GPa", None))
        self.label_23.setText(QCoreApplication.translate("Form", u"GPa", None))
        self.label_22.setText(QCoreApplication.translate("Form", u"GPa", None))
        self.label_21.setText(QCoreApplication.translate("Form", u"GPa", None))
        self.label_12.setText(QCoreApplication.translate("Form", u"S (Voigt):", None))
        self.label_13.setText(QCoreApplication.translate("Form", u"S (Reuss):", None))
        self.label_14.setText(QCoreApplication.translate("Form", u"S (Voigt-Reuss-Hill):", None))
        self.label_8.setText(QCoreApplication.translate("Form", u"Poisson's ratio:", None))
        self.lineEdit_9.setText("")
        self.lineEdit_8.setText("")
        self.lineEdit_7.setText("")
        self.lineEdit_3.setText("")
        self.label_16.setText(QCoreApplication.translate("Form", u"GPa", None))
        self.label_17.setText(QCoreApplication.translate("Form", u"GPa", None))
        self.label_18.setText(QCoreApplication.translate("Form", u"GPa", None))
        self.label_19.setText("")
        self.pushMore.setText(QCoreApplication.translate("Form", u"More...", None))
        self.pushLoadElastic.setText(QCoreApplication.translate("Form", u"Load tensor...", None))
        self.pushButton_2.setText(QCoreApplication.translate("Form", u"Calculate", None))
        self.pushSave.setText(QCoreApplication.translate("Form", u"Save and Close", None))
    # retranslateUi




from PySide6.QtWidgets import  QDialog, QFileDialog
from debyetools.tpropsgui.ui_dialog_doscar import Ui_Dialog as Ui_DOSCAR

from debyetools.aux_functions import load_doscar as dt_load_doscar
from debyetools.electronic import fit_electronic as dt_fit_electronic

import numpy as np

from PySide6.QtCore import QTimer
from PySide6.QtGui import QPixmap, QPalette

def highlight_line_edit(line_edit, color="purple", duration=100):
    # Set the background color
    line_edit.setStyleSheet(f"background-color: {color};")

    # Create a QTimer to reset the color after `duration` milliseconds
    timer = QTimer(line_edit)
    timer.setSingleShot(True)  # Only trigger once
    timer.timeout.connect(lambda: line_edit.setStyleSheet(""))  # Reset the color
    timer.start(duration)




class dialogDoscar(QDialog):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.ui = Ui_DOSCAR()
        self.ui.setupUi(self)

        self.ui.browse.clicked.connect(self.getfiles)
        self.ui.pushExit.clicked.connect(self.on_pushButton_OK)
        self.ui.pushCalc.clicked.connect(self.on_pushCalc)
        self.filepath='.'

        # Connect the textChanged signals to a shared color change method
        self.ui.filepath.textChanged.connect(lambda: self.on_text_changed(self.ui.filepath))
        self.ui.lineEdit_el.textChanged.connect(lambda: self.on_text_changed(self.ui.lineEdit_el))


    def get_EvV(self):
        if self.ui.radioButton.isChecked():
            conv = [(1e-30 * 6.02e23), (0.160218e-18 * 6.02214e23)]
        elif self.ui.radioButton_3.isChecked():
            conv =[1, 1]

        txt = self.ui.EvVText.toPlainText().split('\n')
        data_lst = []
        for ti in txt:
            if len(ti)==0:continue
            if ti[0]=='#': continue
            data_lst.append([float(tii) for tii in ti.split()])
        data = np.array(data_lst)
        ncols = len(data.T)
        return (data[:,i]*conv[i] for i in range(ncols))


    def get_el_params(self):
        txt = self.external_iparams.text()
        if txt=='':
            return 3e-01, -1e+04, 5e-04, 1e-06
        return  [float(ti) for ti in txt.replace(' ','').split(',')]

    def on_pushCalc(self):
        # Vdata, Edata = self.get_EvV()
        status  = 0
        try:
            print(self.Vdata)
            status = 1
        except:
            print('error: Energy curve probably not loaded yet.')

        if status == 1:
            E, N, Ef = dt_load_doscar('', list_filetags = self.filepath_list)
            p_el_initial = self.get_el_params()
            p_electronic = dt_fit_electronic(self.Vdata, p_el_initial,E,N,Ef)
            self.ui.lineEdit_el.setText(', '.join(['%.9e' % (p) for p in p_electronic]))


    def getfiles(self):
        # Open the file dialog and allow multiple file selection
        options = QFileDialog.Options()
        files, _ = QFileDialog.getOpenFileNames(
            self,
            "Select Files",
            "",
            "All Files (*);;Text Files (*.txt);;Python Files (*.py)",
            options=options
        )

        files.sort()
        if files:
            print("Selected files:")
            for file in files:
                print(file)
        filepath = '; '.join(files)
        #filepath = QFileDialog.getExistingDirectory(self, caption='Select a folder')
        self.ui.filepath.setText(filepath)
        self.filepath_list = files

    def on_pushButton_OK(self):
        # self.filepath_list = self.ui.filepath.text()
        self.external_iparams.setText(self.ui.lineEdit_el.text())
        self.close()

    def is_dark_mode(self):
        # Detect if the application is in dark mode using the palette
        palette = self.palette()
        return palette.color(QPalette.ColorRole.Window).value() < 128  # Lightness threshold for dark mode

    def on_text_changed(self, line_edit):
        # Call the reusable highlight function
        dark_mode = self.is_dark_mode()
        color_p = "purple" if dark_mode else "#94a2c9"

        highlight_line_edit(line_edit, color=color_p, duration=500)
        # Update label with the current content of the edited line edit



from debyetools.ndeb import nDeb
from debyetools import potentials
from debyetools.aux_functions import gen_Ts,load_V_E
from debyetools.poisson import poisson_ratio
from debyetools.electronic import fit_electronic
from debyetools.aux_functions import load_EM
from debyetools.aux_functions import load_doscar

m = 0.021971375
V_data, E_data = load_V_E('../Al3Li_L12/SUMMARY', '../Al3Li_L12/CONTCAR')
V_data, E_data = V_data*(1E-30*6.02E+23), E_data*(1.60218E-19 * 6.02214E+23)

params_initial_guess = [-3e5, 1e-5, 7e10, 4]
eos = potentials.BM()
eos.fitEOS(V_data, E_data, params_initial_guess)

EM = load_EM( '../Al3Li_L12/OUTCAR_elastic')
nu = poisson_ratio (EM)

p_el_initial = [3.8e-01,-1.9e-02,
                5.3e-04,-7.0e-06]

list_filetags = ['01','02','03','04',
                 '05','06','07','08',
                 '09','10','11','12',
                 '13','14','15','16',
                 '17','18','19','20','21']
E, N, Ef = load_doscar('../Al3Li_L12/DOSCAR.EvV.',
                       list_filetags=list_filetags)
params_electronic = fit_electronic(V_data, p_el_initial, E, N, Ef)


params_defects = [8.46, 1.69, 933, 0.1]
params_anh, params_intanh = [0,0,0], [0, 1]

ndeb = nDeb (nu , m, params_intanh , eos , params_electronic , params_defects , params_anh )
T_initial, T_final = 0.1, 1000.1
T = gen_Ts ( T_initial , T_final , 10 )
T,V = ndeb.min_G(T,initial_V=1e-5,P=0)
print(V)
# array([9.98852539e-06, 9.99974297e-06, 1.00578469e-05, 1.01135875e-05,
#        1.01419825e-05, 1.02392921e-05, 1.03467847e-05, 1.04650048e-05,
#        1.05953063e-05, 1.07396467e-05, 1.09045695e-05, 1.10973163e-05])



import itertools as it
import re
import numpy as np
from typing import Tuple


class logging(object):
    def __init__(self, *files: ...) -> None:
        self.files = files

    def write(self, obj: str) -> None:
        for f in self.files:
            f.write(obj)
            f.flush()

    def flush(self) -> None:
        for f in self.files:
            f.flush()


def c_types(atom_types: str) -> Tuple[list, list]:
    """
    returns all the pair types combinations.

    :param str atom_types: the types of each atom in the primitive cell in the same order as the basis vectors.
    :return: pair types and list wuth individual types.
    :rtype: Tuple[list, list]
    """
    types_all = re.findall('[A-Z][^A-Z]*', atom_types)
    ptypes = list(set([s for s in types_all]))
    ptypes.sort()
    combs_types = list(it.combinations_with_replacement(ptypes, r=2))
    combs_types = [A[0] + '-' + A[1] for A in combs_types]
    return combs_types, types_all


def generate_cells_coordinates(size: np.ndarray, primitive_cell: np.ndarray, center: np.ndarray) -> np.ndarray:
    """ generate the cell coordinates for which we are going
    to calculate the neighbor list.

    :param np.ndarray size: Number of times we are replicating the primitive cell
    :param np.ndarray primitive_cell: The primitive cell
    :param np.ndarray center: The position in space where the system of reference is
    :return: cell coordinates.
    :rtype: np.ndarray

    """

    cell_coords = np.array(list((it.product(np.arange(size[0]),
                                            np.arange(size[1]),
                                            np.arange(size[2])))))

    cell_coords_centered = cell_coords + center
    cell_coords_centered = np.dot(cell_coords_centered, primitive_cell)

    return cell_coords_centered


def gen_Ts(Ti: float, Tf: float, nTs: int) -> np.ndarray:
    """
    Function to generate a range of temperatures.

    :param float Ti: Initial temperature. (Try not to use the value 0. Use 0.1 instead.)
    :param float Tf: Final temperature.
    :param int nTs: Number of values. This does not include room temperature, which is included anyways.

    :retun np.ndarray: Values of temperatures between Ti and Tf, inclusive, plus room temperature.
    """
    minF_step = (Tf - Ti) / (nTs - 1.)
    Ts = np.arange(Ti, Tf + minF_step, minF_step)
    Ts = np.r_[Ts, [298.15]]
    Ts.sort()
    return Ts


def gen_Ps(Pi, Pf, nPs):
    """
    Function to generate a range of pressures.

    :param float Pi: Initial pressure.
    :param float Pf: Final pressure.
    :param int nPs: Number of values. This does not include room pressure, which is included anyways.

    :retun: Values of pressures between Pi and Pf.
    :rtype: np.ndarray
    """
    if nPs <= 1: return np.array([Pi])
    minF_step = (Pf - Pi) / (nPs - 1.)
    Ps = np.arange(Pi, Pf + 1, minF_step)

    return Ps


def load_doscar(filename_sufix: str, list_filetags: list = None) -> tuple[list, list, list]:
    """
    Extract electronic density, energies and Fermi level as function of volume from DOSCAR's.
    :param filename_sufix: folder path.
    :type filename_sufix: str
    :param list_filetags: filename tags.
    :type list_filetags: list
    :return: E,N,Ef.
    :rtype: tuple[list,list,list]
    """
    if list_filetags is None:
        list_filetags = ['-0.10', '-0.09', '-0.08', '-0.07', '-0.06', '-0.05', '-0.04', '-0.03',
                         '-0.02', '-0.01', '-0.00', '0.01', '0.02', '0.03', '0.04', '0.05', '0.06',
                         '0.07', '0.08', '0.09', '0.10']

    list_filetags = [str(li) for li in list_filetags]
    E = []
    N = []
    Ef = []
    nat = 0
    for dosfile in list_filetags:
        countline = 0
        EN = []

        filename = filename_sufix + dosfile
        with open(filename) as infile:
            for line in infile:
                if countline == 0:
                    nat = float(line.split()[0])
                if countline == 5:
                    Ef.append(float(line.split()[3]))
                if countline > 5:
                    EN.append(line.split()[0:2])

                countline += 1
        ENAl = np.array(EN)
        # print(dosfile, EN)
        E.append([float(s) for s in list(ENAl[:, 0])])
        N.append([float(s) / nat for s in list(ENAl[:, 1])])

    return E, N, Ef


def load_V_E(energy_dir_summary: str, energy_dir_contcar: str, units: str = 'eV/atom') -> tuple[np.ndarray, np.ndarray]:
    """
    Loads Energy curve as function of volume from VASP outputs.
    :param energy_dir_summary: Summary file path.
    :type energy_dir_summary: str
    :param energy_dir_contcar: Atoms positions file path.
    :type energy_dir_contcar: str
    :param units: units.
    :type units: str
    :return: Energy as function of volume
    :rtype: tuple[np.ndarray,np.ndarray]
    """
    with open(energy_dir_contcar, 'r') as f_poscar:
        f_poscar_lines = f_poscar.readlines()
        cell_poscar = f_poscar_lines[2:5]

        cell_lst = [c.split() for c in cell_poscar]
        diag_cell = [float(c[i]) for i, c in enumerate(cell_lst)]

        try:
            nat = sum([int(li) for li in np.fromstring(f_poscar_lines[5], dtype=int, sep=' ')])
            1 / nat
        except:
            nat = sum([int(li) for li in np.fromstring(f_poscar_lines[6], dtype=int, sep=' ')])
            1 / nat
    with open(energy_dir_summary) as f_summary:
        f_summary_lines = f_summary.readlines()
        f_summary_lines = list(dict.fromkeys(f_summary_lines))
        ds = []
        E = []
        for l in f_summary_lines:
            l_lst = l.split(' ')
            ds.append(float(l_lst[0]))
            E.append(float(l_lst[3]) / nat)

    V = []
    for di in ds:
        V.append(np.product(np.array(diag_cell) * (1 + di)) / nat)

    uconvV, uconvE = None, None
    if units == 'J/mol':
        uconvE = (0.160218e-18 * 6.02214e23)
        uconvV = (1e-30 * 6.02e23)
    elif units == 'eV/atom':
        uconvE, uconvV = 1, 1
    return np.array(V).T * uconvV, np.array(E).T * uconvE


def load_EM(filename_outcar_eps: str) -> np.ndarray:
    """
    Extract the stiffness tensor from the VASP output (OUTCAR for IBRION=6).
    :param filename_outcar_eps: file path.
    :type filename_outcar_eps: str
    :return: Stiffness tensor.
    :rtype: np.ndarray
    """
    EM = []

    with open(filename_outcar_eps) as f:
        lines = f.readlines()
        for i, line in enumerate(lines):
            if line.startswith('  SYMMETRIZED ELASTIC MODULI (kBar)'):
                j = i + 3
                data = lines[j:j + 6]
                break

    for line in data:
        EM += [[float(x) for x in line.split()[1:]]]
    EM = np.array(EM)

    return EM


def load_cell(filename_contcar: str) -> tuple[str, np.ndarray, np.ndarray]:
    """
    Extract crystal structure from file in VASP format (POSCAR or CONTCAR).
    :param filename_contcar: File path
    :type filename_contcar: str
    :return: formula,, cell, and basis.
    :rtype: tuple[str,np.ndarray,np.ndarray]
    """
    with open(filename_contcar) as f:
        poscar_lines = f.readlines()
    mult = float(poscar_lines[1])
    cell = np.array([np.fromstring(line_i, dtype=float, sep=' ') for line_i in poscar_lines[2:5]])
    cell = cell * mult

    ix_nats = 6
    re.findall('[A-Z][^A-Z]*', 'ABC')
    ats_types = re.findall('[A-Z][^A-Z]*',
                           poscar_lines[ix_nats - 1].replace('  ', '').replace(' ', '').replace('\n', ''))
    ats_types = [ai + 'x' for ai in ats_types]
    nats = np.fromstring(poscar_lines[ix_nats], dtype=int, sep=' ')

    formula_lst = []
    for at_i, na_i in zip(ats_types, nats):
        formula_lst.append(at_i * na_i)
    formula = ''.join(formula_lst)
    tots_nats = sum(nats)

    basis = np.array([np.fromstring(line_i, dtype=float, sep=' ') for line_i in poscar_lines[8:8 + tots_nats]])
    # basis = np.dot(basis,cell)

    return formula.replace('x', ''), cell, basis

# #####
# from debyetools.tpropsgui.atomtools import atomic_mass
# import pandas as pd
# from debyetools.aux_functions import load_doscar
# from get_elastic import get_EM
#
#
# class Vdata:
#     def __init__(self):
#         pass
#
#
# def parse_contcar(file_path):
#     try:
#         with open(file_path, 'r') as f:
#             lines = [line.strip() for line in f if line.strip()]
#     except FileNotFoundError:
#         print(f"Error: File '{file_path}' not found.")
#
#     if len(lines) < 7:
#         print("Error: The CONTCAR file is too short to be valid.")
#
#     line6 = lines[5]
#     line7 = lines[6]
#
#     # Determine if line6 contains species or counts
#     if all(item.isdigit() for item in line6.split()):
#         # Line6 contains counts, species not provided
#         print("Error: Element symbols not provided in the CONTCAR file.")
#     else:
#         species = line6.split()
#         counts = list(map(int, line7.split()))
#         if len(species) != len(counts):
#             print("Error: The number of species and counts do not match.")
#
#         formula = []
#         for elem, count in zip(species, counts):
#             formula.extend([elem] * count)
#
#         return formula
#
#
# def average_mass(elements):
#     # Calculate the sum of the masses of the elements in the list
#     atomic_mass['VA'] = 0
#     total_mass = sum(atomic_mass[element] for element in elements)
#     # Calculate the average mass
#     average = total_mass / len(elements)
#     return average
#
#
# def load_energies(file_path):
#     # Read the data into a DataFrame, skipping the first line and using whitespace as the delimiter
#     df = pd.read_csv(file_path, skiprows=1, sep=r'\s+', header=None)
#     # Assign column names based on the header information in the data
#     df.columns = ["Element", "Structure", "Total-energy", "Mag", "A-conv", "Vol-conv", "Vol-at", "R-at", "B/A", "C/A"]
#
#     return df
#
#
# def get_energy(potential):
#     energies_df = load_energies('elements_energies.out')
#     # Query the DataFrame to find the total energy of the element
#     total_energy = energies_df[energies_df['Element'] == potential]['Total-energy'].iloc[0]
#     # print(f"Energy of {element}: {total_energy}")
#     return total_energy
#
#
# def extract_from_DFT(file_path):
#     vdata = Vdata()
#
#     # Extract total energy from DFT calculations
#     path = file_path  # '.'
#     E = []
#     V = []
#     nats = 0
#     E0 = 0
#     vi = 70
#     vf = 130
#     step = 3
#     potentials_set = []
#     for i in range(vi, vf + step, step):
#         try:
#             with open(f'{path}/EvV/{i}/OUTCAR') as f:
#                 Ei = 0
#                 Vi = 0
#                 natsi = 0
#                 lines = f.readlines()
#             for line in lines:
#                 if 'volume of cell' in line:
#                     Vi = float(line.split()[-1])
#                 if 'TOTEN' in line:
#                     Ei = float(line.split()[4])
#                 if 'NIONS' in line:
#                     natsi = float(line.split()[-1])
#                 if 'POTCAR:' in line:
#                     potentials_set.append(line.split()[2])
#             E.append(Ei / natsi)
#             V.append(Vi / natsi)
#             nats = natsi
#             if i == 100:
#                 E0 = Ei / natsi
#
#         except Exception as e:
#             print(f'Warning [process_configurations]: {e}\n')
#     vdata.V = V
#     vdata.E = E
#     potentials_set = set(potentials_set)
#     vdata.potentials = {p.split('_')[0]: p for p in potentials_set}
#     vdata.potentials['VA'] = 'VA'
#
#     vdata.formula = parse_contcar(f'{path}/relaxation/CONTCAR')
#     vdata.nats = nats
#     # compound.multiplicities = multiplicities
#     vdata.mass = average_mass(vdata.formula) / 1000
#     vdata.Ef = E0 - sum([get_energy(vdata.potentials[fi]) for fi in vdata.formula]) / nats  # sum(multiplicities)
#     vdata.E0 = E0
#     vdata.path = path
#
#     list_filetags = [f'/EvV/{i}/DOSCAR' for i in range(70, 130 + 3, 3)]
#     vdata.electric = load_doscar(path, list_filetags=list_filetags)
#
#     EM = get_EM(f'{path}/elastic')
#     # try:
#     #     EM = load_EM(f'{path}/elastic/OUTCAR')
#     # except Exception as e:
#     #     EM = None
#     #     print( f'Warning [process_configurations]: Elastic Moduli not found for {path}.\n')
#     #     print(e)
#     vdata.EM = EM
#
#     return vdata


# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'dialog_doscar.ui'
##
## Created by: Qt User Interface Compiler version 6.7.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QDialog, QHBoxLayout, QLineEdit,
    QPushButton, QSizePolicy, QSpacerItem, QVBoxLayout,
    QWidget)

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        if not Dialog.objectName():
            Dialog.setObjectName(u"Dialog")
        Dialog.setWindowModality(Qt.WindowModality.WindowModal)
        Dialog.resize(359, 142)
        self.verticalLayout = QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(-1, 5, -1, 5)
        self.filepath = QLineEdit(Dialog)
        self.filepath.setObjectName(u"filepath")

        self.horizontalLayout.addWidget(self.filepath)

        self.browse = QPushButton(Dialog)
        self.browse.setObjectName(u"browse")

        self.horizontalLayout.addWidget(self.browse)


        self.verticalLayout.addLayout(self.horizontalLayout)

        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.horizontalLayout_3.setContentsMargins(-1, 5, -1, 5)
        self.lineEdit_el = QLineEdit(Dialog)
        self.lineEdit_el.setObjectName(u"lineEdit_el")

        self.horizontalLayout_3.addWidget(self.lineEdit_el)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_3.addItem(self.horizontalSpacer_2)

        self.pushCalc = QPushButton(Dialog)
        self.pushCalc.setObjectName(u"pushCalc")

        self.horizontalLayout_3.addWidget(self.pushCalc)

        self.verticalLayout_3 = QVBoxLayout()
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")

        self.horizontalLayout_3.addLayout(self.verticalLayout_3)


        self.verticalLayout.addLayout(self.horizontalLayout_3)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setContentsMargins(-1, 5, -1, 5)
        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_2.addItem(self.horizontalSpacer)

        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_2.addItem(self.verticalSpacer)

        self.pushExit = QPushButton(Dialog)
        self.pushExit.setObjectName(u"pushExit")

        self.verticalLayout_2.addWidget(self.pushExit)


        self.horizontalLayout_2.addLayout(self.verticalLayout_2)


        self.verticalLayout.addLayout(self.horizontalLayout_2)


        self.retranslateUi(Dialog)

        QMetaObject.connectSlotsByName(Dialog)
    # setupUi

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(QCoreApplication.translate("Dialog", u"debyetools - [select DOSCAR files...]", None))
        self.filepath.setText("")
        self.browse.setText(QCoreApplication.translate("Dialog", u"Browse", None))
        self.lineEdit_el.setText("")
        self.pushCalc.setText(QCoreApplication.translate("Dialog", u"calculate parameters", None))
        self.pushExit.setText(QCoreApplication.translate("Dialog", u"Save and close", None))
    # retranslateUi




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'cp_window.ui'
##
## Created by: Qt User Interface Compiler version 6.7.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QComboBox, QHBoxLayout, QHeaderView,
    QLabel, QLineEdit, QMainWindow, QMenuBar,
    QProgressBar, QPushButton, QRadioButton, QSizePolicy,
    QSpacerItem, QStatusBar, QTableWidget, QTableWidgetItem,
    QVBoxLayout, QWidget)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.setWindowModality(Qt.WindowModality.WindowModal)
        MainWindow.resize(760, 566)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.horizontalLayout_9 = QHBoxLayout(self.centralwidget)
        self.horizontalLayout_9.setObjectName(u"horizontalLayout_9")
        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")

        self.verticalLayout_2.addLayout(self.horizontalLayout)

        self.horizontalLayout_8 = QHBoxLayout()
        self.horizontalLayout_8.setObjectName(u"horizontalLayout_8")
        self.horizontalSpacer_5 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_8.addItem(self.horizontalSpacer_5)

        self.label_12 = QLabel(self.centralwidget)
        self.label_12.setObjectName(u"label_12")

        self.horizontalLayout_8.addWidget(self.label_12)

        self.comboBox_2 = QComboBox(self.centralwidget)
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.setObjectName(u"comboBox_2")

        self.horizontalLayout_8.addWidget(self.comboBox_2)


        self.verticalLayout_2.addLayout(self.horizontalLayout_8)

        self.verticalLayout_2.setStretch(0, 9)

        self.horizontalLayout_9.addLayout(self.verticalLayout_2)

        self.verticalLayout_3 = QVBoxLayout()
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.verticalLayout_3.setContentsMargins(-1, -1, -1, 10)
        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_2.addItem(self.horizontalSpacer)

        self.label = QLabel(self.centralwidget)
        self.label.setObjectName(u"label")
        self.label.setMinimumSize(QSize(110, 0))
        self.label.setMaximumSize(QSize(120, 16777215))

        self.horizontalLayout_2.addWidget(self.label)

        self.lineEdit = QLineEdit(self.centralwidget)
        self.lineEdit.setObjectName(u"lineEdit")
        sizePolicy = QSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit.sizePolicy().hasHeightForWidth())
        self.lineEdit.setSizePolicy(sizePolicy)

        self.horizontalLayout_2.addWidget(self.lineEdit)

        self.label_4 = QLabel(self.centralwidget)
        self.label_4.setObjectName(u"label_4")
        self.label_4.setMinimumSize(QSize(20, 0))

        self.horizontalLayout_2.addWidget(self.label_4)


        self.verticalLayout_3.addLayout(self.horizontalLayout_2)

        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_3.addItem(self.horizontalSpacer_2)

        self.label_2 = QLabel(self.centralwidget)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setMinimumSize(QSize(110, 0))
        self.label_2.setMaximumSize(QSize(120, 16777215))

        self.horizontalLayout_3.addWidget(self.label_2)

        self.lineEdit_2 = QLineEdit(self.centralwidget)
        self.lineEdit_2.setObjectName(u"lineEdit_2")
        sizePolicy.setHeightForWidth(self.lineEdit_2.sizePolicy().hasHeightForWidth())
        self.lineEdit_2.setSizePolicy(sizePolicy)

        self.horizontalLayout_3.addWidget(self.lineEdit_2)

        self.label_3 = QLabel(self.centralwidget)
        self.label_3.setObjectName(u"label_3")
        self.label_3.setMinimumSize(QSize(20, 0))

        self.horizontalLayout_3.addWidget(self.label_3)


        self.verticalLayout_3.addLayout(self.horizontalLayout_3)

        self.horizontalLayout_4 = QHBoxLayout()
        self.horizontalLayout_4.setObjectName(u"horizontalLayout_4")
        self.radioButton = QRadioButton(self.centralwidget)
        self.radioButton.setObjectName(u"radioButton")
        self.radioButton.setChecked(True)

        self.horizontalLayout_4.addWidget(self.radioButton)

        self.radioButton_2 = QRadioButton(self.centralwidget)
        self.radioButton_2.setObjectName(u"radioButton_2")

        self.horizontalLayout_4.addWidget(self.radioButton_2)

        self.radioButton_3 = QRadioButton(self.centralwidget)
        self.radioButton_3.setObjectName(u"radioButton_3")

        self.horizontalLayout_4.addWidget(self.radioButton_3)


        self.verticalLayout_3.addLayout(self.horizontalLayout_4)

        self.horizontalLayout_5 = QHBoxLayout()
        self.horizontalLayout_5.setObjectName(u"horizontalLayout_5")
        self.label_7 = QLabel(self.centralwidget)
        self.label_7.setObjectName(u"label_7")

        self.horizontalLayout_5.addWidget(self.label_7)

        self.horizontalSpacer_3 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_5.addItem(self.horizontalSpacer_3)


        self.verticalLayout_3.addLayout(self.horizontalLayout_5)

        self.horizontalLayout_6 = QHBoxLayout()
        self.horizontalLayout_6.setSpacing(2)
        self.horizontalLayout_6.setObjectName(u"horizontalLayout_6")
        self.label_5 = QLabel(self.centralwidget)
        self.label_5.setObjectName(u"label_5")

        self.horizontalLayout_6.addWidget(self.label_5)

        self.lineEdit_3 = QLineEdit(self.centralwidget)
        self.lineEdit_3.setObjectName(u"lineEdit_3")
        sizePolicy.setHeightForWidth(self.lineEdit_3.sizePolicy().hasHeightForWidth())
        self.lineEdit_3.setSizePolicy(sizePolicy)
        self.lineEdit_3.setMaximumSize(QSize(150, 16777215))

        self.horizontalLayout_6.addWidget(self.lineEdit_3)

        self.label_6 = QLabel(self.centralwidget)
        self.label_6.setObjectName(u"label_6")

        self.horizontalLayout_6.addWidget(self.label_6)

        self.label_9 = QLabel(self.centralwidget)
        self.label_9.setObjectName(u"label_9")

        self.horizontalLayout_6.addWidget(self.label_9)

        self.lineEdit_4 = QLineEdit(self.centralwidget)
        self.lineEdit_4.setObjectName(u"lineEdit_4")
        sizePolicy.setHeightForWidth(self.lineEdit_4.sizePolicy().hasHeightForWidth())
        self.lineEdit_4.setSizePolicy(sizePolicy)
        self.lineEdit_4.setMaximumSize(QSize(200, 16777215))

        self.horizontalLayout_6.addWidget(self.lineEdit_4)

        self.label_8 = QLabel(self.centralwidget)
        self.label_8.setObjectName(u"label_8")

        self.horizontalLayout_6.addWidget(self.label_8)

        self.label_10 = QLabel(self.centralwidget)
        self.label_10.setObjectName(u"label_10")

        self.horizontalLayout_6.addWidget(self.label_10)

        self.comboBox = QComboBox(self.centralwidget)
        self.comboBox.setObjectName(u"comboBox")
        self.comboBox.setMaximumSize(QSize(300, 16777214))

        self.horizontalLayout_6.addWidget(self.comboBox)

        self.label_11 = QLabel(self.centralwidget)
        self.label_11.setObjectName(u"label_11")

        self.horizontalLayout_6.addWidget(self.label_11)


        self.verticalLayout_3.addLayout(self.horizontalLayout_6)

        self.tableWidget = QTableWidget(self.centralwidget)
        if (self.tableWidget.columnCount() < 2):
            self.tableWidget.setColumnCount(2)
        __qtablewidgetitem = QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(0, __qtablewidgetitem)
        __qtablewidgetitem1 = QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(1, __qtablewidgetitem1)
        if (self.tableWidget.rowCount() < 8):
            self.tableWidget.setRowCount(8)
        __qtablewidgetitem2 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(0, __qtablewidgetitem2)
        __qtablewidgetitem3 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(1, __qtablewidgetitem3)
        __qtablewidgetitem4 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(2, __qtablewidgetitem4)
        __qtablewidgetitem5 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(3, __qtablewidgetitem5)
        __qtablewidgetitem6 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(4, __qtablewidgetitem6)
        __qtablewidgetitem7 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(5, __qtablewidgetitem7)
        __qtablewidgetitem8 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(6, __qtablewidgetitem8)
        __qtablewidgetitem9 = QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(7, __qtablewidgetitem9)
        __qtablewidgetitem10 = QTableWidgetItem()
        __qtablewidgetitem10.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(0, 1, __qtablewidgetitem10)
        __qtablewidgetitem11 = QTableWidgetItem()
        __qtablewidgetitem11.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(1, 1, __qtablewidgetitem11)
        __qtablewidgetitem12 = QTableWidgetItem()
        __qtablewidgetitem12.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(2, 1, __qtablewidgetitem12)
        __qtablewidgetitem13 = QTableWidgetItem()
        __qtablewidgetitem13.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(3, 1, __qtablewidgetitem13)
        __qtablewidgetitem14 = QTableWidgetItem()
        __qtablewidgetitem14.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(4, 1, __qtablewidgetitem14)
        __qtablewidgetitem15 = QTableWidgetItem()
        __qtablewidgetitem15.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(5, 1, __qtablewidgetitem15)
        __qtablewidgetitem16 = QTableWidgetItem()
        __qtablewidgetitem16.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(6, 1, __qtablewidgetitem16)
        __qtablewidgetitem17 = QTableWidgetItem()
        __qtablewidgetitem17.setFlags(Qt.ItemIsSelectable|Qt.ItemIsDragEnabled|Qt.ItemIsDropEnabled|Qt.ItemIsUserCheckable|Qt.ItemIsEnabled);
        self.tableWidget.setItem(7, 1, __qtablewidgetitem17)
        self.tableWidget.setObjectName(u"tableWidget")
        self.tableWidget.setMinimumSize(QSize(0, 270))
        self.tableWidget.setMaximumSize(QSize(320, 16777215))

        self.verticalLayout_3.addWidget(self.tableWidget)

        self.horizontalLayout_7 = QHBoxLayout()
        self.horizontalLayout_7.setObjectName(u"horizontalLayout_7")
        self.verticalLayout_4 = QVBoxLayout()
        self.verticalLayout_4.setSpacing(1)
        self.verticalLayout_4.setObjectName(u"verticalLayout_4")
        self.verticalSpacer_2 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_4.addItem(self.verticalSpacer_2)

        self.pushBack = QPushButton(self.centralwidget)
        self.pushBack.setObjectName(u"pushBack")

        self.verticalLayout_4.addWidget(self.pushBack)

        self.progress_2 = QProgressBar(self.centralwidget)
        self.progress_2.setObjectName(u"progress_2")
        self.progress_2.setMaximumSize(QSize(16777215, 2))
        self.progress_2.setValue(0)
        self.progress_2.setTextVisible(False)
        self.progress_2.setInvertedAppearance(False)

        self.verticalLayout_4.addWidget(self.progress_2)


        self.horizontalLayout_7.addLayout(self.verticalLayout_4)

        self.horizontalSpacer_4 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_7.addItem(self.horizontalSpacer_4)

        self.verticalLayout = QVBoxLayout()
        self.verticalLayout.setSpacing(1)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout.addItem(self.verticalSpacer)

        self.pushButton = QPushButton(self.centralwidget)
        self.pushButton.setObjectName(u"pushButton")
        self.pushButton.setEnabled(True)

        self.verticalLayout.addWidget(self.pushButton)

        self.progress = QProgressBar(self.centralwidget)
        self.progress.setObjectName(u"progress")
        self.progress.setMaximumSize(QSize(16777215, 2))
        self.progress.setValue(0)
        self.progress.setTextVisible(False)
        self.progress.setInvertedAppearance(False)

        self.verticalLayout.addWidget(self.progress)


        self.horizontalLayout_7.addLayout(self.verticalLayout)

        self.verticalLayout_5 = QVBoxLayout()
        self.verticalLayout_5.setSpacing(1)
        self.verticalLayout_5.setObjectName(u"verticalLayout_5")
        self.verticalLayout_5.setContentsMargins(-1, -1, 0, -1)
        self.verticalSpacer_3 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_5.addItem(self.verticalSpacer_3)

        self.pushExport = QPushButton(self.centralwidget)
        self.pushExport.setObjectName(u"pushExport")

        self.verticalLayout_5.addWidget(self.pushExport)

        self.progress_3 = QProgressBar(self.centralwidget)
        self.progress_3.setObjectName(u"progress_3")
        self.progress_3.setMaximumSize(QSize(16777215, 2))
        self.progress_3.setValue(0)
        self.progress_3.setTextVisible(False)
        self.progress_3.setInvertedAppearance(False)

        self.verticalLayout_5.addWidget(self.progress_3)


        self.horizontalLayout_7.addLayout(self.verticalLayout_5)


        self.verticalLayout_3.addLayout(self.horizontalLayout_7)

        self.horizontalLayout_10 = QHBoxLayout()
        self.horizontalLayout_10.setObjectName(u"horizontalLayout_10")
        self.horizontalLayout_10.setContentsMargins(-1, 0, -1, -1)
        self.horizontalSpacer_6 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_10.addItem(self.horizontalSpacer_6)

        self.pushCloseAll = QPushButton(self.centralwidget)
        self.pushCloseAll.setObjectName(u"pushCloseAll")

        self.horizontalLayout_10.addWidget(self.pushCloseAll)


        self.verticalLayout_3.addLayout(self.horizontalLayout_10)


        self.horizontalLayout_9.addLayout(self.verticalLayout_3)

        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 760, 21))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"debyetools - [termodynamic properties]", None))
        self.label_12.setText(QCoreApplication.translate("MainWindow", u"                                                                           property to plot:", None))
        self.comboBox_2.setItemText(0, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(1, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(2, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(3, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(4, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(5, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(6, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(7, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(8, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(9, QCoreApplication.translate("MainWindow", u"New Item", None))
        self.comboBox_2.setItemText(10, QCoreApplication.translate("MainWindow", u"New Item", None))

        self.label.setText(QCoreApplication.translate("MainWindow", u"Temperature range:", None))
        self.lineEdit.setText(QCoreApplication.translate("MainWindow", u"0.1 1000.1 100", None))
        self.label_4.setText(QCoreApplication.translate("MainWindow", u"K", None))
        self.label_2.setText(QCoreApplication.translate("MainWindow", u"Pressure:", None))
        self.lineEdit_2.setText(QCoreApplication.translate("MainWindow", u"0 30 10", None))
        self.label_3.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.radioButton.setText(QCoreApplication.translate("MainWindow", u"Slater", None))
        self.radioButton_2.setText(QCoreApplication.translate("MainWindow", u"Dugdale-MacDonald", None))
        self.radioButton_3.setText(QCoreApplication.translate("MainWindow", u"mean-free-volume", None))
        self.label_7.setText(QCoreApplication.translate("MainWindow", u"FactSage parameters:", None))
        self.label_5.setText(QCoreApplication.translate("MainWindow", u"From:", None))
        self.lineEdit_3.setText(QCoreApplication.translate("MainWindow", u"298.15", None))
        self.label_6.setText(QCoreApplication.translate("MainWindow", u"K", None))
        self.label_9.setText(QCoreApplication.translate("MainWindow", u"to:", None))
        self.lineEdit_4.setText(QCoreApplication.translate("MainWindow", u"1000.1", None))
        self.label_8.setText(QCoreApplication.translate("MainWindow", u"K", None))
        self.label_10.setText(QCoreApplication.translate("MainWindow", u"P:", None))
        self.label_11.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        ___qtablewidgetitem = self.tableWidget.horizontalHeaderItem(0)
        ___qtablewidgetitem.setText(QCoreApplication.translate("MainWindow", u"Values", None));
        ___qtablewidgetitem1 = self.tableWidget.verticalHeaderItem(0)
        ___qtablewidgetitem1.setText(QCoreApplication.translate("MainWindow", u"G+TS (T=298.15)", None));
        ___qtablewidgetitem2 = self.tableWidget.verticalHeaderItem(1)
        ___qtablewidgetitem2.setText(QCoreApplication.translate("MainWindow", u"S (T=298.15)", None));
        ___qtablewidgetitem3 = self.tableWidget.verticalHeaderItem(2)
        ___qtablewidgetitem3.setText(QCoreApplication.translate("MainWindow", u"C0", None));
        ___qtablewidgetitem4 = self.tableWidget.verticalHeaderItem(3)
        ___qtablewidgetitem4.setText(QCoreApplication.translate("MainWindow", u"C1", None));
        ___qtablewidgetitem5 = self.tableWidget.verticalHeaderItem(4)
        ___qtablewidgetitem5.setText(QCoreApplication.translate("MainWindow", u"C2", None));
        ___qtablewidgetitem6 = self.tableWidget.verticalHeaderItem(5)
        ___qtablewidgetitem6.setText(QCoreApplication.translate("MainWindow", u"C3", None));
        ___qtablewidgetitem7 = self.tableWidget.verticalHeaderItem(6)
        ___qtablewidgetitem7.setText(QCoreApplication.translate("MainWindow", u"C4", None));
        ___qtablewidgetitem8 = self.tableWidget.verticalHeaderItem(7)
        ___qtablewidgetitem8.setText(QCoreApplication.translate("MainWindow", u"C5", None));

        __sortingEnabled = self.tableWidget.isSortingEnabled()
        self.tableWidget.setSortingEnabled(False)
        ___qtablewidgetitem9 = self.tableWidget.item(0, 1)
        ___qtablewidgetitem9.setText(QCoreApplication.translate("MainWindow", u"J/mol-at", None));
        ___qtablewidgetitem10 = self.tableWidget.item(1, 1)
        ___qtablewidgetitem10.setText(QCoreApplication.translate("MainWindow", u"J/K/mol-at", None));
        ___qtablewidgetitem11 = self.tableWidget.item(2, 1)
        ___qtablewidgetitem11.setText(QCoreApplication.translate("MainWindow", u"T^(0)", None));
        ___qtablewidgetitem12 = self.tableWidget.item(3, 1)
        ___qtablewidgetitem12.setText(QCoreApplication.translate("MainWindow", u"T^(1)", None));
        ___qtablewidgetitem13 = self.tableWidget.item(4, 1)
        ___qtablewidgetitem13.setText(QCoreApplication.translate("MainWindow", u"T^(-2)", None));
        ___qtablewidgetitem14 = self.tableWidget.item(5, 1)
        ___qtablewidgetitem14.setText(QCoreApplication.translate("MainWindow", u"T^(2)", None));
        ___qtablewidgetitem15 = self.tableWidget.item(6, 1)
        ___qtablewidgetitem15.setText(QCoreApplication.translate("MainWindow", u"T^(-0.5)", None));
        ___qtablewidgetitem16 = self.tableWidget.item(7, 1)
        ___qtablewidgetitem16.setText(QCoreApplication.translate("MainWindow", u"T^(-3)", None));
        self.tableWidget.setSortingEnabled(__sortingEnabled)

        self.pushBack.setText(QCoreApplication.translate("MainWindow", u"<back", None))
        self.pushButton.setText(QCoreApplication.translate("MainWindow", u"re-calculate", None))
        self.pushExport.setText(QCoreApplication.translate("MainWindow", u"export parameters", None))
        self.pushCloseAll.setText(QCoreApplication.translate("MainWindow", u"close all...", None))
    # retranslateUi

